@@ -1,39 +1,29 @@
+import base64
 import binascii
-from codecs import utf_8_decode
-from codecs import utf_8_encode
+from codecs import utf_8_decode, utf_8_encode
 from collections import namedtuple
 import hashlib
-import base64
 import re
 import time as time_mod
+from urllib.parse import quote, unquote
 import warnings
-
+from webob.cookies import CookieProfile
 from zope.interface import implementer
 
-from webob.cookies import CookieProfile
-
-from pyramid.compat import (
-    long,
-    text_type,
-    binary_type,
-    url_unquote,
-    url_quote,
-    bytes_,
-    ascii_native_,
-    native_,
-)
-
+from pyramid.authorization import Authenticated, Everyone
 from pyramid.interfaces import IAuthenticationPolicy, IDebugLogger
-
-from pyramid.security import Authenticated, Everyone
-
-from pyramid.util import strings_differ
-from pyramid.util import SimpleSerializer
+from pyramid.util import (
+    SimpleSerializer,
+    ascii_,
+    bytes_,
+    strings_differ,
+    text_,
+)
 
 VALID_TOKEN = re.compile(r"^[A-Za-z][A-Za-z0-9+_-]*$")
 
 
-class CallbackAuthenticationPolicy(object):
+class CallbackAuthenticationPolicy:
     """ Abstract class """
 
     debug = False
@@ -53,7 +43,7 @@ class CallbackAuthenticationPolicy(object):
         return princid
 
     def authenticated_userid(self, request):
-        """ Return the authenticated userid or ``None``.
+        """Return the authenticated userid or ``None``.
 
         If no callback is registered, this will be the same as
         ``unauthenticated_userid``.
@@ -105,10 +95,10 @@ class CallbackAuthenticationPolicy(object):
         )
 
     def effective_principals(self, request):
-        """ A list of effective principals derived from request.
+        """A list of effective principals derived from request.
 
         This will return a list of principals including, at least,
-        :data:`pyramid.security.Everyone`. If there is no authenticated
+        :data:`pyramid.authorization.Everyone`. If there is no authenticated
         userid, or the ``callback`` returns ``None``, this will be the
         only principal:
 
@@ -118,8 +108,9 @@ class CallbackAuthenticationPolicy(object):
 
         If the ``callback`` does not return ``None`` and an authenticated
         userid is found, then the principals will include
-        :data:`pyramid.security.Authenticated`, the ``authenticated_userid``
-        and the list of principals returned by the ``callback``:
+        :data:`pyramid.authorization.Authenticated`, the
+        ``authenticated_userid`` and the list of principals returned by the
+        ``callback``:
 
         .. code-block:: python
 
@@ -188,7 +179,7 @@ class CallbackAuthenticationPolicy(object):
 
 @implementer(IAuthenticationPolicy)
 class RepozeWho1AuthenticationPolicy(CallbackAuthenticationPolicy):
-    """ A :app:`Pyramid` :term:`authentication policy` which
+    """A :app:`Pyramid` :term:`authentication policy` which
     obtains data from the :mod:`repoze.who` 1.X WSGI 'API' (the
     ``repoze.who.identity`` key in the WSGI environment).
 
@@ -227,7 +218,7 @@ class RepozeWho1AuthenticationPolicy(CallbackAuthenticationPolicy):
         return identifier
 
     def authenticated_userid(self, request):
-        """ Return the authenticated userid or ``None``.
+        """Return the authenticated userid or ``None``.
 
         If no callback is registered, this will be the same as
         ``unauthenticated_userid``.
@@ -281,16 +272,17 @@ class RepozeWho1AuthenticationPolicy(CallbackAuthenticationPolicy):
         return identity['repoze.who.userid']
 
     def effective_principals(self, request):
-        """ A list of effective principals derived from the identity.
+        """A list of effective principals derived from the identity.
 
         This will return a list of principals including, at least,
-        :data:`pyramid.security.Everyone`. If there is no identity, or
+        :data:`pyramid.authorization.Everyone`. If there is no identity, or
         the ``callback`` returns ``None``, this will be the only principal.
 
         If the ``callback`` does not return ``None`` and an identity is
         found, then the principals will include
-        :data:`pyramid.security.Authenticated`, the ``authenticated_userid``
-        and the list of principals returned by the ``callback``.
+        :data:`pyramid.authorization.Authenticated`, the
+        ``authenticated_userid`` and the list of principals returned by the
+        ``callback``.
 
         """
         effective_principals = [Everyone]
@@ -353,7 +345,7 @@ class RepozeWho1AuthenticationPolicy(CallbackAuthenticationPolicy):
         return effective_principals
 
     def remember(self, request, userid, **kw):
-        """ Store the ``userid`` as ``repoze.who.userid``.
+        """Store the ``userid`` as ``repoze.who.userid``.
 
         The identity to authenticated to :mod:`repoze.who`
         will contain the given userid as ``userid``, and
@@ -369,7 +361,7 @@ class RepozeWho1AuthenticationPolicy(CallbackAuthenticationPolicy):
         return identifier.remember(environ, identity)
 
     def forget(self, request):
-        """ Forget the current authenticated user.
+        """Forget the current authenticated user.
 
         Return headers that, if included in a response, will delete the
         cookie responsible for tracking the current user.
@@ -384,7 +376,7 @@ class RepozeWho1AuthenticationPolicy(CallbackAuthenticationPolicy):
 
 @implementer(IAuthenticationPolicy)
 class RemoteUserAuthenticationPolicy(CallbackAuthenticationPolicy):
-    """ A :app:`Pyramid` :term:`authentication policy` which
+    """A :app:`Pyramid` :term:`authentication policy` which
     obtains data from the ``REMOTE_USER`` WSGI environment variable.
 
     Constructor Arguments
@@ -423,13 +415,13 @@ class RemoteUserAuthenticationPolicy(CallbackAuthenticationPolicy):
         return request.environ.get(self.environ_key)
 
     def remember(self, request, userid, **kw):
-        """ A no-op. The ``REMOTE_USER`` does not provide a protocol for
+        """A no-op. The ``REMOTE_USER`` does not provide a protocol for
         remembering the user. This will be application-specific and can
         be done somewhere else or in a subclass."""
         return []
 
     def forget(self, request):
-        """ A no-op. The ``REMOTE_USER`` does not provide a protocol for
+        """A no-op. The ``REMOTE_USER`` does not provide a protocol for
         forgetting the user. This will be application-specific and can
         be done somewhere else or in a subclass."""
         return []
@@ -579,9 +571,7 @@ class AuthTktAuthenticationPolicy(CallbackAuthenticationPolicy):
     ``samesite``
 
         Default: ``'Lax'``.  The 'samesite' option of the session cookie. Set
-        the value to ``None`` to turn off the samesite option.
-
-        This option is available as of :app:`Pyramid` 1.10.
+        the value to the string ``'None'`` to turn off the samesite option.
 
     .. versionchanged:: 1.4
 
@@ -647,7 +637,7 @@ class AuthTktAuthenticationPolicy(CallbackAuthenticationPolicy):
             return result['userid']
 
     def remember(self, request, userid, **kw):
-        """ Accepts the following kw args: ``max_age=<int-seconds>,
+        """Accepts the following kw args: ``max_age=<int-seconds>,
         ``tokens=<sequence-of-ascii-strings>``.
 
         Return a list of headers which will set appropriate cookies on
@@ -670,7 +660,7 @@ def b64decode(v):
 
 
 # this class licensed under the MIT license (stolen from Paste)
-class AuthTicket(object):
+class AuthTicket:
     """
     This class represents an authentication token.  You must pass in
     the shared secret, the userid, and the IP address.  Optionally you
@@ -727,11 +717,7 @@ class AuthTicket(object):
         )
 
     def cookie_value(self):
-        v = '%s%08x%s!' % (
-            self.digest(),
-            int(self.time),
-            url_quote(self.userid),
-        )
+        v = '%s%08x%s!' % (self.digest(), int(self.time), quote(self.userid))
         if self.tokens:
             v += self.tokens + '!'
         v += self.user_data
@@ -759,7 +745,7 @@ def parse_ticket(secret, ticket, ip, hashalg='md5'):
     If the ticket cannot be parsed, a ``BadTicket`` exception will be raised
     with an explanation.
     """
-    ticket = native_(ticket).strip('"')
+    ticket = text_(ticket).strip('"')
     digest_size = hashlib.new(hashalg).digest_size * 2
     digest = ticket[:digest_size]
     try:
@@ -770,7 +756,7 @@ def parse_ticket(secret, ticket, ip, hashalg='md5'):
         userid, data = ticket[digest_size + 8 :].split('!', 1)
     except ValueError:
         raise BadTicket('userid is not followed by !')
-    userid = url_unquote(userid)
+    userid = unquote(userid)
     if '!' in data:
         tokens, user_data = data.split('!', 1)
     else:  # pragma: no cover (never generated)
@@ -835,12 +821,148 @@ def encode_ip_timestamp(ip, timestamp):
     return bytes_(ip_chars + ts_chars)
 
 
-class AuthTktCookieHelper(object):
+class AuthTktCookieHelper:
     """
-    A helper class for use in third-party authentication policy
-    implementations.  See
-    :class:`pyramid.authentication.AuthTktAuthenticationPolicy` for the
-    meanings of the constructor arguments.
+    A helper class for security policies that obtains data from an "auth
+    ticket" cookie.
+
+    Constructor Arguments
+
+    ``secret``
+
+       The secret (a string) used for auth_tkt cookie signing.  This value
+       should be unique across all values provided to Pyramid for various
+       subsystem secrets (see :ref:`admonishment_against_secret_sharing`).
+       Required.
+
+    ``cookie_name``
+
+       Default: ``auth_tkt``.  The cookie name used
+       (string).  Optional.
+
+    ``secure``
+
+       Default: ``False``.  Only send the cookie back over a secure
+       conn.  Optional.
+
+    ``include_ip``
+
+       Default: ``False``.  Make the requesting IP address part of
+       the authentication data in the cookie.  Optional.
+
+       For IPv6 this option is not recommended. The ``mod_auth_tkt``
+       specification does not specify how to handle IPv6 addresses, so using
+       this option in combination with IPv6 addresses may cause an
+       incompatible cookie. It ties the authentication ticket to that
+       individual's IPv6 address.
+
+    ``timeout``
+
+       Default: ``None``.  Maximum number of seconds which a newly
+       issued ticket will be considered valid.  After this amount of
+       time, the ticket will expire (effectively logging the user
+       out).  If this value is ``None``, the ticket never expires.
+       Optional.
+
+    ``reissue_time``
+
+       Default: ``None``.  If this parameter is set, it represents the number
+       of seconds that must pass before an authentication token cookie is
+       automatically reissued as the result of a request which requires
+       authentication.  The duration is measured as the number of seconds
+       since the last auth_tkt cookie was issued and 'now'.  If this value is
+       ``0``, a new ticket cookie will be reissued on every request which
+       requires authentication.
+
+       A good rule of thumb: if you want auto-expired cookies based on
+       inactivity: set the ``timeout`` value to 1200 (20 mins) and set the
+       ``reissue_time`` value to perhaps a tenth of the ``timeout`` value
+       (120 or 2 mins).  It's nonsensical to set the ``timeout`` value lower
+       than the ``reissue_time`` value, as the ticket will never be reissued
+       if so.  However, such a configuration is not explicitly prevented.
+
+       Optional.
+
+    ``max_age``
+
+       Default: ``None``.  The max age of the auth_tkt cookie, in
+       seconds.  This differs from ``timeout`` inasmuch as ``timeout``
+       represents the lifetime of the ticket contained in the cookie,
+       while this value represents the lifetime of the cookie itself.
+       When this value is set, the cookie's ``Max-Age`` and
+       ``Expires`` settings will be set, allowing the auth_tkt cookie
+       to last between browser sessions.  It is typically nonsensical
+       to set this to a value that is lower than ``timeout`` or
+       ``reissue_time``, although it is not explicitly prevented.
+       Optional.
+
+    ``path``
+
+       Default: ``/``. The path for which the auth_tkt cookie is valid.
+       May be desirable if the application only serves part of a domain.
+       Optional.
+
+    ``http_only``
+
+       Default: ``False``. Hide cookie from JavaScript by setting the
+       HttpOnly flag. Not honored by all browsers.
+       Optional.
+
+    ``wild_domain``
+
+       Default: ``True``. An auth_tkt cookie will be generated for the
+       wildcard domain. If your site is hosted as ``example.com`` this
+       will make the cookie available for sites underneath ``example.com``
+       such as ``www.example.com``.
+       Optional.
+
+    ``parent_domain``
+
+       Default: ``False``. An auth_tkt cookie will be generated for the
+       parent domain of the current site. For example if your site is
+       hosted under ``www.example.com`` a cookie will be generated for
+       ``.example.com``. This can be useful if you have multiple sites
+       sharing the same domain. This option supercedes the ``wild_domain``
+       option.
+       Optional.
+
+    ``domain``
+
+       Default: ``None``. If provided the auth_tkt cookie will only be
+       set for this domain. This option is not compatible with ``wild_domain``
+       and ``parent_domain``.
+       Optional.
+
+    ``hashalg``
+
+       Default: ``sha512`` (the literal string).
+
+       Any hash algorithm supported by Python's ``hashlib.new()`` function
+       can be used as the ``hashalg``.
+
+       Cookies generated by different instances of AuthTktAuthenticationPolicy
+       using different ``hashalg`` options are not compatible. Switching the
+       ``hashalg`` will imply that all existing users with a valid cookie will
+       be required to re-login.
+
+       Optional.
+
+    ``debug``
+
+        Default: ``False``.  If ``debug`` is ``True``, log messages to the
+        Pyramid debug logger about the results of various authentication
+        steps.  The output from debugging is useful for reporting to maillist
+        or IRC channels when asking for support. Optional.
+
+    ``samesite``
+
+        Default: ``'Lax'``.  The 'samesite' option of the session cookie. Set
+        the value to ``None`` to turn off the samesite option. Optional.
+
+    .. versionchanged:: 2.0
+
+        The default ``hashalg`` was changed from ``md5`` to ``sha512``.
+
     """
 
     parse_ticket = staticmethod(parse_ticket)  # for tests
@@ -857,9 +979,8 @@ class AuthTktCookieHelper(object):
 
     userid_type_encoders = {
         int: ('int', str),
-        long: ('int', str),
-        text_type: ('b64unicode', lambda x: b64encode(utf_8_encode(x)[0])),
-        binary_type: ('b64str', lambda x: b64encode(x)),
+        str: ('b64unicode', lambda x: b64encode(utf_8_encode(x)[0])),
+        bytes: ('b64str', lambda x: b64encode(x)),
     }
 
     def __init__(
@@ -874,21 +995,18 @@ class AuthTktCookieHelper(object):
         http_only=False,
         path="/",
         wild_domain=True,
-        hashalg='md5',
+        hashalg='sha512',
         parent_domain=False,
         domain=None,
         samesite='Lax',
     ):
-
-        serializer = SimpleSerializer()
-
         self.cookie_profile = CookieProfile(
             cookie_name=cookie_name,
             secure=secure,
             max_age=max_age,
             httponly=http_only,
             path=path,
-            serializer=serializer,
+            serializer=SimpleSerializer(),
             samesite=samesite,
         )
 
@@ -907,24 +1025,20 @@ class AuthTktCookieHelper(object):
         self.hashalg = hashalg
 
     def _get_cookies(self, request, value, max_age=None):
-        cur_domain = request.domain
-
-        domains = []
         if self.domain:
-            domains.append(self.domain)
+            domain = self.domain
         else:
+            cur_domain = request.domain
             if self.parent_domain and cur_domain.count('.') > 1:
-                domains.append('.' + cur_domain.split('.', 1)[1])
+                domain = cur_domain.split('.', 1)[1]
+            elif self.wild_domain:
+                domain = cur_domain
             else:
-                domains.append(None)
-                domains.append(cur_domain)
-                if self.wild_domain:
-                    domains.append('.' + cur_domain)
+                domain = None
 
         profile = self.cookie_profile(request)
 
-        kw = {}
-        kw['domains'] = domains
+        kw = {'domains': [domain]}
         if max_age is not None:
             kw['max_age'] = max_age
 
@@ -932,7 +1046,7 @@ class AuthTktCookieHelper(object):
         return headers
 
     def identify(self, request):
-        """ Return a dictionary with authentication information, or ``None``
+        """Return a dictionary with authentication information, or ``None``
         if no valid auth_tkt is attached to ``request``"""
         environ = request.environ
         cookie = request.cookies.get(self.cookie_name)
@@ -1000,13 +1114,13 @@ class AuthTktCookieHelper(object):
         return identity
 
     def forget(self, request):
-        """ Return a set of expires Set-Cookie headers, which will destroy
+        """Return a set of expires Set-Cookie headers, which will destroy
         any existing auth_tkt cookie when attached to a response"""
         request._authtkt_reissue_revoked = True
         return self._get_cookies(request, None)
 
     def remember(self, request, userid, max_age=None, tokens=()):
-        """ Return a set of Set-Cookie headers; when set into a response,
+        """Return a set of Set-Cookie headers; when set into a response,
         these headers will represent a valid authentication ticket.
 
         ``max_age``
@@ -1048,7 +1162,7 @@ class AuthTktCookieHelper(object):
                 "type provided.".format(type(userid)),
                 RuntimeWarning,
             )
-            encoding, encoder = self.userid_type_encoders.get(text_type)
+            encoding, encoder = self.userid_type_encoders.get(str)
             userid = str(userid)
 
         userid = encoder(userid)
@@ -1056,9 +1170,9 @@ class AuthTktCookieHelper(object):
 
         new_tokens = []
         for token in tokens:
-            if isinstance(token, text_type):
+            if isinstance(token, str):
                 try:
-                    token = ascii_native_(token)
+                    token = ascii_(token)
                 except UnicodeEncodeError:
                     raise ValueError("Invalid token %r" % (token,))
             if not (isinstance(token, str) and VALID_TOKEN.match(token)):
@@ -1086,7 +1200,7 @@ class AuthTktCookieHelper(object):
 
 @implementer(IAuthenticationPolicy)
 class SessionAuthenticationPolicy(CallbackAuthenticationPolicy):
-    """ A :app:`Pyramid` authentication policy which gets its data from the
+    """A :app:`Pyramid` authentication policy which gets its data from the
     configured :term:`session`.  For this authentication policy to work, you
     will have to follow the instructions in the :ref:`sessions_chapter` to
     configure a :term:`session factory`.
@@ -1117,28 +1231,56 @@ class SessionAuthenticationPolicy(CallbackAuthenticationPolicy):
 
     def __init__(self, prefix='auth.', callback=None, debug=False):
         self.callback = callback
-        self.prefix = prefix or ''
-        self.userid_key = prefix + 'userid'
         self.debug = debug
+        self.helper = SessionAuthenticationHelper(prefix)
+
+    def remember(self, request, userid, **kw):
+        """ Store a userid in the session."""
+        return self.helper.remember(request, userid, **kw)
+
+    def forget(self, request):
+        """ Remove the stored userid from the session."""
+        return self.helper.forget(request)
+
+    def unauthenticated_userid(self, request):
+        return self.helper.authenticated_userid(request)
+
+
+class SessionAuthenticationHelper:
+    """A helper for use with a :term:`security policy` which stores user data
+    in the configured :term:`session`.
+
+    Constructor Arguments
+
+    ``prefix``
+
+       A prefix used when storing the authentication parameters in the
+       session. Defaults to 'auth.'. Optional.
+
+    """
+
+    def __init__(self, prefix='auth.'):
+        self.userid_key = prefix + 'userid'
 
     def remember(self, request, userid, **kw):
         """ Store a userid in the session."""
         request.session[self.userid_key] = userid
         return []
 
-    def forget(self, request):
+    def forget(self, request, **kw):
         """ Remove the stored userid from the session."""
         if self.userid_key in request.session:
             del request.session[self.userid_key]
         return []
 
-    def unauthenticated_userid(self, request):
+    def authenticated_userid(self, request):
+        """ Return the stored userid."""
         return request.session.get(self.userid_key)
 
 
 @implementer(IAuthenticationPolicy)
 class BasicAuthAuthenticationPolicy(CallbackAuthenticationPolicy):
-    """ A :app:`Pyramid` authentication policy which uses HTTP standard basic
+    """A :app:`Pyramid` authentication policy which uses HTTP standard basic
     authentication protocol to authenticate users.  To use this policy you will
     need to provide a callback which checks the supplied user credentials
     against your source of login data.
@@ -1196,14 +1338,14 @@ class BasicAuthAuthenticationPolicy(CallbackAuthenticationPolicy):
             return credentials.username
 
     def remember(self, request, userid, **kw):
-        """ A no-op. Basic authentication does not provide a protocol for
+        """A no-op. Basic authentication does not provide a protocol for
         remembering the user. Credentials are sent on every request.
 
         """
         return []
 
     def forget(self, request):
-        """ Returns challenge headers. This should be attached to a response
+        """Returns challenge headers. This should be attached to a response
         to indicate that credentials are required."""
         return [('WWW-Authenticate', 'Basic realm="%s"' % self.realm)]
 
@@ -1224,7 +1366,7 @@ HTTPBasicCredentials = namedtuple(
 
 
 def extract_http_basic_credentials(request):
-    """ A helper function for extraction of HTTP Basic credentials
+    """A helper function for extraction of HTTP Basic credentials
     from a given :term:`request`.
 
     Returns a :class:`.HTTPBasicCredentials` 2-tuple with ``username`` and
