@@ -1,9 +1,9 @@
 from pyramid.threadlocal import get_current_registry
 
 
-class ZCAConfiguratorMixin(object):
+class ZCAConfiguratorMixin:
     def hook_zca(self):
-        """ Call :func:`zope.component.getSiteManager.sethook` with the
+        """Call :func:`zope.component.getSiteManager.sethook` with the
         argument :data:`pyramid.threadlocal.get_current_registry`, causing
         the :term:`Zope Component Architecture` 'global' APIs such as
         :func:`zope.component.getSiteManager`,
@@ -15,7 +15,7 @@ class ZCAConfiguratorMixin(object):
         getSiteManager.sethook(get_current_registry)
 
     def unhook_zca(self):
-        """ Call :func:`zope.component.getSiteManager.reset` to undo the
+        """Call :func:`zope.component.getSiteManager.reset` to undo the
         action of :meth:`pyramid.config.Configurator.hook_zca`."""
         from zope.component import getSiteManager
 
