@@ -1,8 +1,5 @@
-from functools import update_wrapper
-
-
-class reify(object):
-    """ Use as a class method decorator.  It operates almost exactly like the
+class reify:
+    """Use as a class method decorator.  It operates almost exactly like the
     Python ``@property`` decorator, but it puts the result of the method it
     decorates into the instance dict after the first call, effectively
     replacing the function it decorates with an instance variable.  It is, in
@@ -13,7 +10,7 @@ class reify(object):
 
         >>> from pyramid.decorator import reify
 
-        >>> class Foo(object):
+        >>> class Foo:
         ...     @reify
         ...     def jammy(self):
         ...         print('jammy called')
@@ -35,11 +32,15 @@ class reify(object):
 
     def __init__(self, wrapped):
         self.wrapped = wrapped
-        update_wrapper(self, wrapped)
+        self.__doc__ = wrapped.__doc__
 
     def __get__(self, inst, objtype=None):
         if inst is None:
             return self
         val = self.wrapped(inst)
+        # reify is a non-data-descriptor which is leveraging the fact
+        # that it is not invoked if the equivalent attribute is defined in the
+        # object's dict, so the setattr here effectively hides this descriptor
+        # from subsequent lookups
         setattr(inst, self.wrapped.__name__, val)
         return val
