@@ -129,30 +129,24 @@ subclasses have one additional keyword argument: ``location``,
 which indicates the location to which to redirect.
 """
 import json
-
 from string import Template
-
-from zope.interface import implementer
-
 from webob import html_escape as _html_escape
 from webob.acceptparse import create_accept_header
-
-from pyramid.compat import class_types, text_type, binary_type, text_
+from zope.interface import implementer
 
 from pyramid.interfaces import IExceptionResponse
 from pyramid.response import Response
+from pyramid.util import text_
 
 
 def _no_escape(value):
     if value is None:
         return ''
-    if not isinstance(value, text_type):
-        if hasattr(value, '__unicode__'):
-            value = value.__unicode__()
-        if isinstance(value, binary_type):
+    if not isinstance(value, str):
+        if isinstance(value, bytes):
             value = text_(value, 'utf-8')
         else:
-            value = text_type(value)
+            value = str(value)
     return value
 
 
@@ -284,7 +278,7 @@ ${body}'''
                 if comment:
                     html_comment = escape(comment)
 
-                class JsonPageTemplate(object):
+                class JsonPageTemplate:
                     def __init__(self, excobj):
                         self.excobj = excobj
 
@@ -326,7 +320,7 @@ ${body}'''
                     args[k.lower()] = escape(v)
             body = body_tmpl.substitute(args)
             page = page_template.substitute(status=self.status, body=body)
-            if isinstance(page, text_type):
+            if isinstance(page, str):
                 page = page.encode(self.charset if self.charset else 'UTF-8')
             self.app_iter = [page]
             self.body = page
@@ -368,7 +362,7 @@ class HTTPRedirection(HTTPException):
 
     This is an abstract base class for 3xx redirection.  It indicates
     that further action needs to be taken by the user agent in order
-    to fulfill the request.  It does not necessarly signal an error
+    to fulfill the request.  It does not necessarily signal an error
     condition.
     """
 
@@ -538,7 +532,7 @@ ${html_comment}'''
     ):
         if location is None:
             raise ValueError("HTTP redirects need a location to redirect to.")
-        super(_HTTPMove, self).__init__(
+        super().__init__(
             detail=detail,
             headers=headers,
             comment=comment,
@@ -759,11 +753,12 @@ class HTTPForbidden(HTTPClientError):
     argument, ``detail``, should be a string.  The value of this string will
     be used as the ``message`` attribute of the exception object.  The second
     special keyword argument, ``result`` is usually an instance of
-    :class:`pyramid.security.Denied` or :class:`pyramid.security.ACLDenied`
-    each of which indicates a reason for the forbidden error.  However,
-    ``result`` is also permitted to be just a plain boolean ``False`` object
-    or ``None``.  The ``result`` value will be used as the ``result``
-    attribute of the exception object.  It defaults to ``None``.
+    :class:`pyramid.security.Denied` or
+    :class:`pyramid.authorization.ACLDenied` each of which indicates a reason
+    for the forbidden error.  However, ``result`` is also permitted to be just
+    a plain boolean ``False`` object or ``None``.  The ``result`` value will
+    be used as the ``result`` attribute of the exception object.
+    It defaults to ``None``.
 
     The :term:`Forbidden View` can use the attributes of a Forbidden
     exception as necessary to provide extended information in an error
@@ -915,9 +910,7 @@ class HTTPConflict(HTTPClientError):
 
     code = 409
     title = 'Conflict'
-    explanation = (
-        'There was a conflict when trying to complete ' 'your request.'
-    )
+    explanation = 'There was a conflict when trying to complete your request.'
 
 
 class HTTPGone(HTTPClientError):
@@ -1041,7 +1034,7 @@ class HTTPExpectationFailed(HTTPClientError):
     """
     subclass of :class:`~HTTPClientError`
 
-    This indidcates that the expectation given in an Expect
+    This indicates that the expectation given in an Expect
     request-header field could not be met by this server.
 
     code: 417, title: Expectation Failed
@@ -1331,7 +1324,7 @@ status_map = {}
 code = None
 for name, value in list(globals().items()):
     if (
-        isinstance(value, class_types)
+        isinstance(value, type)
         and issubclass(value, HTTPException)
         and value not in {HTTPClientError, HTTPServerError}
         and not name.startswith('_')
