@@ -9,6 +9,7 @@
 # lib/site.py
 
 import argparse
+import hupper
 import os
 import re
 import sys
@@ -17,13 +18,8 @@ import threading
 import time
 import webbrowser
 
-import hupper
-
-from pyramid.compat import PY2
-
-from pyramid.scripts.common import get_config_loader
-from pyramid.scripts.common import parse_vars
 from pyramid.path import AssetResolver
+from pyramid.scripts.common import get_config_loader, parse_vars
 from pyramid.settings import aslist
 
 
@@ -34,7 +30,7 @@ def main(argv=sys.argv, quiet=False, original_ignore_files=None):
     return command.run()
 
 
-class PServeCommand(object):
+class PServeCommand:
 
     description = """\
     This command serves a web application that uses a PasteDeploy
@@ -147,7 +143,7 @@ class PServeCommand(object):
 
     def out(self, msg):  # pragma: no cover
         if self.args.verbose > 0:
-            print(msg)
+            print(msg, file=sys.stderr)
 
     def get_config_path(self, loader):
         return os.path.abspath(loader.uri.path)
@@ -300,7 +296,9 @@ def wsgiref_server_runner(wsgi_app, global_conf, **kw):  # pragma: no cover
     host = kw.get('host', '0.0.0.0')
     port = int(kw.get('port', 8080))
     server = make_server(host, port, wsgi_app)
-    print('Starting HTTP server on http://%s:%s' % (host, port))
+    print(
+        'Starting HTTP server on http://%s:%s' % (host, port), file=sys.stderr
+    )
     server.serve_forever()
 
 
@@ -402,18 +400,15 @@ def cherrypy_server_runner(
 
     server = WSGIServer(bind_addr, app, server_name=server_name, **kwargs)
     if ssl_pem is not None:
-        if PY2:
-            server.ssl_certificate = server.ssl_private_key = ssl_pem
-        else:
-            # creates wsgiserver.ssl_builtin as side-effect
-            try:
-                from cheroot.server import get_ssl_adapter_class
-                from cheroot.ssl.builtin import BuiltinSSLAdapter
-            except ImportError:
-                from cherrypy.wsgiserver import get_ssl_adapter_class
-                from cherrypy.wsgiserver.ssl_builtin import BuiltinSSLAdapter
-            get_ssl_adapter_class()
-            server.ssl_adapter = BuiltinSSLAdapter(ssl_pem, ssl_pem)
+        # creates wsgiserver.ssl_builtin as side-effect
+        try:
+            from cheroot.server import get_ssl_adapter_class
+            from cheroot.ssl.builtin import BuiltinSSLAdapter
+        except ImportError:
+            from cherrypy.wsgiserver import get_ssl_adapter_class
+            from cherrypy.wsgiserver.ssl_builtin import BuiltinSSLAdapter
+        get_ssl_adapter_class()
+        server.ssl_adapter = BuiltinSSLAdapter(ssl_pem, ssl_pem)
 
     if protocol_version:
         server.protocol = protocol_version
@@ -423,10 +418,14 @@ def cherrypy_server_runner(
         if host == '0.0.0.0':
             print(
                 'serving on 0.0.0.0:%s view at %s://127.0.0.1:%s'
-                % (port, protocol, port)
+                % (port, protocol, port),
+                file=sys.stderr,
             )
         else:
-            print('serving on %s://%s:%s' % (protocol, host, port))
+            print(
+                'serving on %s://%s:%s' % (protocol, host, port),
+                file=sys.stderr,
+            )
         server.start()
     except (KeyboardInterrupt, SystemExit):
         server.stop()
