@@ -1,7 +1,7 @@
 from pyramid.response import Response
 
 
-class BaseRESTView(object):
+class BaseRESTView:
     def __init__(self, context, request):
         self.context = context
         self.request = request
@@ -11,7 +11,7 @@ class PetRESTView(BaseRESTView):
     """ REST Controller to control action of an avatar """
 
     def __init__(self, context, request):
-        super(PetRESTView, self).__init__(context, request)
+        super().__init__(context, request)
 
     def GET(self):
         return Response('gotten')
