@@ -1,11 +1,11 @@
-class RootFactory(object):
+class RootFactory:
     __acl__ = [('Allow', 'fred', 'view')]
 
     def __init__(self, request):
         pass
 
 
-class LocalRootFactory(object):
+class LocalRootFactory:
     __acl__ = [('Allow', 'bob', 'view')]
 
     def __init__(self, request):
@@ -18,8 +18,8 @@ def includeme(config):
 
     authn_policy = RemoteUserAuthenticationPolicy()
     authz_policy = ACLAuthorizationPolicy()
-    config._set_authentication_policy(authn_policy)
-    config._set_authorization_policy(authz_policy)
+    config.set_authentication_policy(authn_policy)
+    config.set_authorization_policy(authz_policy)
     config.add_static_view('allowed', 'tests:fixtures/static/')
     config.add_static_view(
         'protected', 'tests:fixtures/static/', permission='view'
