@@ -1,8 +1,9 @@
 import unittest
 
-from pyramid.exceptions import ConfigurationConflictError
-from pyramid.exceptions import ConfigurationExecutionError
-
+from pyramid.exceptions import (
+    ConfigurationConflictError,
+    ConfigurationExecutionError,
+)
 from pyramid.interfaces import IRequest
 
 
@@ -22,9 +23,12 @@ class ActionConfiguratorMixinTests(unittest.TestCase):
         exception_view=False,
     ):
         from zope.interface import Interface
-        from pyramid.interfaces import IView
-        from pyramid.interfaces import IViewClassifier
-        from pyramid.interfaces import IExceptionViewClassifier
+
+        from pyramid.interfaces import (
+            IExceptionViewClassifier,
+            IView,
+            IViewClassifier,
+        )
 
         if exception_view:  # pragma: no cover
             classifier = IExceptionViewClassifier
@@ -1040,12 +1044,14 @@ class TestActionInfo(unittest.TestCase):
 
     def test_class_conforms(self):
         from zope.interface.verify import verifyClass
+
         from pyramid.interfaces import IActionInfo
 
         verifyClass(IActionInfo, self._getTargetClass())
 
     def test_instance_conforms(self):
         from zope.interface.verify import verifyObject
+
         from pyramid.interfaces import IActionInfo
 
         verifyObject(IActionInfo, self._makeOne('f', 0, 'f', 'f'))
@@ -1071,7 +1077,7 @@ def _conflictFunctions(e):
             yield confinst.function
 
 
-class DummyActionState(object):
+class DummyActionState:
     autocommit = False
     info = ''
 
@@ -1082,7 +1088,7 @@ class DummyActionState(object):
         self.actions.append((arg, kw))
 
 
-class DummyIntrospectable(object):
+class DummyIntrospectable:
     def __init__(self):
         self.registered = []
 
