@@ -1,20 +1,20 @@
 import os
 import unittest
 
-from pyramid.compat import im_func
-from pyramid.testing import skip_on
-
-from . import dummy_tween_factory
-from . import dummy_include
-from . import dummy_extend
-from . import dummy_extend2
-from . import DummyContext
-
-from pyramid.exceptions import ConfigurationExecutionError
-from pyramid.exceptions import ConfigurationConflictError
-
+from pyramid.exceptions import (
+    ConfigurationConflictError,
+    ConfigurationExecutionError,
+)
 from pyramid.interfaces import IRequest
 
+from . import (
+    DummyContext,
+    dummy_extend,
+    dummy_extend2,
+    dummy_include,
+    dummy_tween_factory,
+)
+
 
 class ConfiguratorTests(unittest.TestCase):
     def _makeOne(self, *arg, **kw):
@@ -31,9 +31,11 @@ class ConfiguratorTests(unittest.TestCase):
         name='',
         exception_view=False,
     ):
-        from pyramid.interfaces import IView
-        from pyramid.interfaces import IViewClassifier
-        from pyramid.interfaces import IExceptionViewClassifier
+        from pyramid.interfaces import (
+            IExceptionViewClassifier,
+            IView,
+            IViewClassifier,
+        )
 
         if exception_view:  # pragma: no cover
             classifier = IExceptionViewClassifier
@@ -66,9 +68,9 @@ class ConfiguratorTests(unittest.TestCase):
 
     def test_ctor_no_registry(self):
         import sys
-        from pyramid.interfaces import ISettings
+
         from pyramid.config import Configurator
-        from pyramid.interfaces import IRendererFactory
+        from pyramid.interfaces import IRendererFactory, ISettings
 
         config = Configurator()
         this_pkg = sys.modules['tests.test_config']
@@ -177,6 +179,7 @@ class ConfiguratorTests(unittest.TestCase):
 
     def test_ctor_with_package_registry(self):
         import sys
+
         from pyramid.config import Configurator
 
         pkg = sys.modules['pyramid']
@@ -208,6 +211,15 @@ class ConfiguratorTests(unittest.TestCase):
         result = config.registry.getUtility(IDebugLogger)
         self.assertEqual(logger, result)
 
+    def test_ctor_security_policy(self):
+        from pyramid.interfaces import ISecurityPolicy
+
+        policy = object()
+        config = self._makeOne(security_policy=policy)
+        config.commit()
+        result = config.registry.getUtility(ISecurityPolicy)
+        self.assertEqual(policy, result)
+
     def test_ctor_authentication_policy(self):
         from pyramid.interfaces import IAuthenticationPolicy
 
@@ -288,8 +300,8 @@ class ConfiguratorTests(unittest.TestCase):
         )
 
     def test_ctor_httpexception_view_default(self):
-        from pyramid.interfaces import IExceptionResponse
         from pyramid.httpexceptions import default_exceptionresponse_view
+        from pyramid.interfaces import IExceptionResponse
 
         config = self._makeOne()
         view = self._getViewCallable(
@@ -419,17 +431,16 @@ class ConfiguratorTests(unittest.TestCase):
         self.assertEqual(reg.events, (1,))
 
     def test__fix_registry_queryAdapterOrSelf(self):
-        from zope.interface import Interface
-        from zope.interface import implementer
+        from zope.interface import Interface, implementer
 
         class IFoo(Interface):
             pass
 
         @implementer(IFoo)
-        class Foo(object):
+        class Foo:
             pass
 
-        class Bar(object):
+        class Bar:
             pass
 
         adaptation = ()
@@ -485,6 +496,7 @@ class ConfiguratorTests(unittest.TestCase):
 
     def test_setup_registry_registers_default_exceptionresponse_views(self):
         from webob.exc import WSGIHTTPException
+
         from pyramid.interfaces import IExceptionResponse
         from pyramid.view import default_exceptionresponse_view
 
@@ -524,6 +536,7 @@ class ConfiguratorTests(unittest.TestCase):
 
     def test_setup_registry_registers_default_webob_iresponse_adapter(self):
         from webob import Response
+
         from pyramid.interfaces import IResponse
 
         config = self._makeOne()
@@ -534,10 +547,11 @@ class ConfiguratorTests(unittest.TestCase):
         )
 
     def test_setup_registry_explicit_notfound_trumps_iexceptionresponse(self):
-        from pyramid.renderers import null_renderer
         from zope.interface import implementedBy
+
         from pyramid.httpexceptions import HTTPNotFound
         from pyramid.registry import Registry
+        from pyramid.renderers import null_renderer
 
         reg = Registry()
         config = self._makeOne(reg, autocommit=True)
@@ -557,8 +571,8 @@ class ConfiguratorTests(unittest.TestCase):
         self.assertEqual(result, 'OK')
 
     def test_setup_registry_custom_settings(self):
-        from pyramid.registry import Registry
         from pyramid.interfaces import ISettings
+        from pyramid.registry import Registry
 
         settings = {'reload_templates': True, 'mysetting': True}
         reg = Registry()
@@ -570,8 +584,8 @@ class ConfiguratorTests(unittest.TestCase):
         self.assertEqual(settings['mysetting'], True)
 
     def test_setup_registry_debug_logger_None_default(self):
-        from pyramid.registry import Registry
         from pyramid.interfaces import IDebugLogger
+        from pyramid.registry import Registry
 
         reg = Registry()
         config = self._makeOne(reg)
@@ -580,8 +594,8 @@ class ConfiguratorTests(unittest.TestCase):
         self.assertEqual(logger.name, 'tests.test_config')
 
     def test_setup_registry_debug_logger_non_None(self):
-        from pyramid.registry import Registry
         from pyramid.interfaces import IDebugLogger
+        from pyramid.registry import Registry
 
         logger = object()
         reg = Registry()
@@ -591,8 +605,8 @@ class ConfiguratorTests(unittest.TestCase):
         self.assertEqual(logger, result)
 
     def test_setup_registry_debug_logger_name(self):
-        from pyramid.registry import Registry
         from pyramid.interfaces import IDebugLogger
+        from pyramid.registry import Registry
 
         reg = Registry()
         config = self._makeOne(reg)
@@ -601,8 +615,8 @@ class ConfiguratorTests(unittest.TestCase):
         self.assertEqual(result.name, 'foo')
 
     def test_setup_registry_authentication_policy(self):
-        from pyramid.registry import Registry
         from pyramid.interfaces import IAuthenticationPolicy
+        from pyramid.registry import Registry
 
         policy = object()
         reg = Registry()
@@ -613,8 +627,8 @@ class ConfiguratorTests(unittest.TestCase):
         self.assertEqual(policy, result)
 
     def test_setup_registry_authentication_policy_dottedname(self):
-        from pyramid.registry import Registry
         from pyramid.interfaces import IAuthenticationPolicy
+        from pyramid.registry import Registry
 
         reg = Registry()
         config = self._makeOne(reg)
@@ -626,8 +640,8 @@ class ConfiguratorTests(unittest.TestCase):
         self.assertEqual(result, tests.test_config)
 
     def test_setup_registry_authorization_policy_dottedname(self):
-        from pyramid.registry import Registry
         from pyramid.interfaces import IAuthorizationPolicy
+        from pyramid.registry import Registry
 
         reg = Registry()
         config = self._makeOne(reg)
@@ -652,8 +666,8 @@ class ConfiguratorTests(unittest.TestCase):
         config = self.assertRaises(ConfigurationExecutionError, config.commit)
 
     def test_setup_registry_no_default_root_factory(self):
-        from pyramid.registry import Registry
         from pyramid.interfaces import IRootFactory
+        from pyramid.registry import Registry
 
         reg = Registry()
         config = self._makeOne(reg)
@@ -662,8 +676,8 @@ class ConfiguratorTests(unittest.TestCase):
         self.assertEqual(reg.queryUtility(IRootFactory), None)
 
     def test_setup_registry_dottedname_root_factory(self):
-        from pyramid.registry import Registry
         from pyramid.interfaces import IRootFactory
+        from pyramid.registry import Registry
 
         reg = Registry()
         config = self._makeOne(reg)
@@ -675,8 +689,8 @@ class ConfiguratorTests(unittest.TestCase):
         self.assertEqual(reg.getUtility(IRootFactory), tests.test_config)
 
     def test_setup_registry_locale_negotiator_dottedname(self):
-        from pyramid.registry import Registry
         from pyramid.interfaces import ILocaleNegotiator
+        from pyramid.registry import Registry
 
         reg = Registry()
         config = self._makeOne(reg)
@@ -689,8 +703,8 @@ class ConfiguratorTests(unittest.TestCase):
         self.assertEqual(utility, tests.test_config)
 
     def test_setup_registry_locale_negotiator(self):
-        from pyramid.registry import Registry
         from pyramid.interfaces import ILocaleNegotiator
+        from pyramid.registry import Registry
 
         reg = Registry()
         config = self._makeOne(reg)
@@ -702,8 +716,8 @@ class ConfiguratorTests(unittest.TestCase):
         self.assertEqual(utility, negotiator)
 
     def test_setup_registry_request_factory(self):
-        from pyramid.registry import Registry
         from pyramid.interfaces import IRequestFactory
+        from pyramid.registry import Registry
 
         reg = Registry()
         config = self._makeOne(reg)
@@ -715,8 +729,8 @@ class ConfiguratorTests(unittest.TestCase):
         self.assertEqual(utility, factory)
 
     def test_setup_registry_response_factory(self):
-        from pyramid.registry import Registry
         from pyramid.interfaces import IResponseFactory
+        from pyramid.registry import Registry
 
         reg = Registry()
         config = self._makeOne(reg)
@@ -728,8 +742,8 @@ class ConfiguratorTests(unittest.TestCase):
         self.assertEqual(utility, factory)
 
     def test_setup_registry_request_factory_dottedname(self):
-        from pyramid.registry import Registry
         from pyramid.interfaces import IRequestFactory
+        from pyramid.registry import Registry
 
         reg = Registry()
         config = self._makeOne(reg)
@@ -742,8 +756,8 @@ class ConfiguratorTests(unittest.TestCase):
         self.assertEqual(utility, tests.test_config)
 
     def test_setup_registry_alternate_renderers(self):
-        from pyramid.registry import Registry
         from pyramid.interfaces import IRendererFactory
+        from pyramid.registry import Registry
 
         renderer = object()
         reg = Registry()
@@ -753,8 +767,8 @@ class ConfiguratorTests(unittest.TestCase):
         self.assertEqual(reg.getUtility(IRendererFactory, 'yeah'), renderer)
 
     def test_setup_registry_default_permission(self):
-        from pyramid.registry import Registry
         from pyramid.interfaces import IDefaultPermission
+        from pyramid.registry import Registry
 
         reg = Registry()
         config = self._makeOne(reg)
@@ -820,8 +834,8 @@ test_config.dummy_include2"""
 
     def test_make_wsgi_app(self):
         import pyramid.config
-        from pyramid.router import Router
         from pyramid.interfaces import IApplicationCreated
+        from pyramid.router import Router
 
         manager = DummyThreadLocalManager()
         config = self._makeOne()
@@ -911,12 +925,13 @@ test_config.dummy_include2"""
         root_config.include(dummy_subapp, route_prefix='nested')
 
     def test_include_with_missing_source_file(self):
-        from pyramid.exceptions import ConfigurationError
         import inspect
 
+        from pyramid.exceptions import ConfigurationError
+
         config = self._makeOne()
 
-        class DummyInspect(object):
+        class DummyInspect:
             def getmodule(self, c):
                 return inspect.getmodule(c)
 
@@ -964,8 +979,9 @@ test_config.dummy_include2"""
 
     def test_scan_integration(self):
         from zope.interface import alsoProvides
+
         from pyramid.view import render_view_to_response
-        import tests.test_config.pkgs.scannable as package
+        from tests.test_config.pkgs import scannable as package
 
         config = self._makeOne(autocommit=True)
         config.scan(package)
@@ -1070,8 +1086,9 @@ test_config.dummy_include2"""
 
     def test_scan_integration_with_ignore(self):
         from zope.interface import alsoProvides
+
         from pyramid.view import render_view_to_response
-        import tests.test_config.pkgs.scannable as package
+        from tests.test_config.pkgs import scannable as package
 
         config = self._makeOne(autocommit=True)
         config.scan(package, ignore='tests.test_config.pkgs.scannable.another')
@@ -1091,6 +1108,7 @@ test_config.dummy_include2"""
 
     def test_scan_integration_dottedname_package(self):
         from zope.interface import alsoProvides
+
         from pyramid.view import render_view_to_response
 
         config = self._makeOne(autocommit=True)
@@ -1107,7 +1125,7 @@ test_config.dummy_include2"""
 
     def test_scan_integration_with_extra_kw(self):
         config = self._makeOne(autocommit=True)
-        config.scan('tests.test_config.pkgs.scanextrakw', a=1)
+        config.scan('tests.test_config.pkgs.scanextrakw', a=1, categories=None)
         self.assertEqual(config.a, 1)
 
     def test_scan_integration_with_onerror(self):
@@ -1134,8 +1152,8 @@ test_config.dummy_include2"""
             sys.path.remove(path)
 
     def test_scan_integration_conflict(self):
-        from tests.test_config.pkgs import selfscan
         from pyramid.config import Configurator
+        from tests.test_config.pkgs import selfscan
 
         c = Configurator()
         c.scan(selfscan)
@@ -1157,7 +1175,6 @@ test_config.dummy_include2"""
                 "@view_config(name='two', renderer='string')" in which
             )
 
-    @skip_on('py3')
     def test_hook_zca(self):
         from zope.component import getSiteManager
 
@@ -1173,7 +1190,6 @@ test_config.dummy_include2"""
         finally:
             getSiteManager.reset()
 
-    @skip_on('py3')
     def test_unhook_zca(self):
         from zope.component import getSiteManager
 
@@ -1208,7 +1224,7 @@ test_config.dummy_include2"""
         directives = {'foo': (foo, True)}
         config.registry._directives = directives
         foo_meth = config.foo
-        self.assertTrue(getattr(foo_meth, im_func).__docobj__ is foo)
+        self.assertTrue(getattr(foo_meth, '__func__').__docobj__ is foo)
 
     def test___getattr__matches_no_action_wrap(self):
         config = self._makeOne()
@@ -1219,7 +1235,7 @@ test_config.dummy_include2"""
         directives = {'foo': (foo, False)}
         config.registry._directives = directives
         foo_meth = config.foo
-        self.assertTrue(getattr(foo_meth, im_func) is foo)
+        self.assertTrue(getattr(foo_meth, '__func__') is foo)
 
 
 class TestConfigurator_add_directive(unittest.TestCase):
@@ -1412,7 +1428,7 @@ class DummyRequest:
         self.cookies = {}
 
 
-class DummyThreadLocalManager(object):
+class DummyThreadLocalManager:
     def __init__(self):
         self.pushed = {'registry': None, 'request': None}
         self.popped = False
@@ -1427,7 +1443,7 @@ class DummyThreadLocalManager(object):
         self.popped = True
 
 
-class DummyRegistry(object):
+class DummyRegistry:
     def __init__(self, adaptation=None, util=None):
         self.utilities = []
         self.adapters = []
@@ -1451,5 +1467,5 @@ class DummyRegistry(object):
         return self.util
 
 
-class DummyPredicate(object):
+class DummyPredicate:
     pass
