@@ -1,17 +1,17 @@
-# -*- coding: utf-8 -*-
 import datetime
 import gc
 import locale
 import os
 import unittest
+from urllib.parse import quote
 from webtest import TestApp
 from zope.interface import Interface
 
-from pyramid.wsgi import wsgiapp
-from pyramid.view import view_config
 from pyramid.static import static_view
 from pyramid.testing import skip_on
-from pyramid.compat import text_, url_quote
+from pyramid.util import text_
+from pyramid.view import view_config
+from pyramid.wsgi import wsgiapp
 
 from .pkgs.exceptionviewapp.models import AnException, NotAnException
 
@@ -34,8 +34,8 @@ def wsgiapptest(environ, start_response):
 
 class WGSIAppPlusViewConfigTests(unittest.TestCase):
     def test_it(self):
-        from venusian import ATTACH_ATTR
         import types
+        from venusian import ATTACH_ATTR
 
         self.assertTrue(getattr(wsgiapptest, ATTACH_ATTR))
         self.assertIsInstance(wsgiapptest, types.FunctionType)
@@ -45,10 +45,9 @@ class WGSIAppPlusViewConfigTests(unittest.TestCase):
         self.assertEqual(result, '123')
 
     def test_scanned(self):
-        from pyramid.interfaces import IRequest
-        from pyramid.interfaces import IView
-        from pyramid.interfaces import IViewClassifier
         from pyramid.config import Configurator
+        from pyramid.interfaces import IRequest, IView, IViewClassifier
+
         from . import test_integration
 
         config = Configurator()
@@ -61,7 +60,7 @@ class WGSIAppPlusViewConfigTests(unittest.TestCase):
         self.assertEqual(view.__original_view__, wsgiapptest)
 
 
-class IntegrationBase(object):
+class IntegrationBase:
     root_factory = None
     package = None
 
@@ -72,8 +71,8 @@ class IntegrationBase(object):
             root_factory=self.root_factory, package=self.package
         )
         config.include(self.package)
-        app = config.make_wsgi_app()
-        self.testapp = TestApp(app)
+        self.app = config.make_wsgi_app()
+        self.testapp = TestApp(self.app)
         self.config = config
 
     def tearDown(self):
@@ -108,7 +107,7 @@ class StaticAppBase(IntegrationBase):
                 os.makedirs(pathdir)
                 with open(path, 'wb') as fp:
                     fp.write(body)
-                url = url_quote('/static/héhé/index.html')
+                url = quote('/static/héhé/index.html')
                 res = self.testapp.get(url, status=200)
                 self.assertEqual(res.body, body)
             finally:
@@ -123,7 +122,7 @@ class StaticAppBase(IntegrationBase):
             with open(path, 'wb') as fp:
                 fp.write(body)
             try:
-                url = url_quote('/static/héhé.html')
+                url = quote('/static/héhé.html')
                 res = self.testapp.get(url, status=200)
                 self.assertEqual(res.body, body)
             finally:
@@ -226,13 +225,65 @@ class TestStaticAppUsingAssetSpec(StaticAppBase, unittest.TestCase):
     package = 'tests.pkgs.static_assetspec'
 
 
+class TestStaticAppWithEncodings(IntegrationBase, unittest.TestCase):
+    package = 'tests.pkgs.static_encodings'
+
+    # XXX webtest actually runs response.decode_content() and so we can't
+    # use it to test gzip- or deflate-encoded responses to see if they
+    # were transferred correctly
+    def _getResponse(self, *args, **kwargs):
+        from pyramid.request import Request
+
+        req = Request.blank(*args, **kwargs)
+        return req.get_response(self.app)
+
+    def test_no_accept(self):
+        res = self._getResponse('/static/encoded.html')
+        self.assertEqual(res.headers['Vary'], 'Accept-Encoding')
+        self.assertNotIn('Content-Encoding', res.headers)
+        _assertBody(
+            res.body, os.path.join(here, 'fixtures/static/encoded.html')
+        )
+
+    def test_unsupported_accept(self):
+        res = self._getResponse(
+            '/static/encoded.html',
+            headers={'Accept-Encoding': 'br, foo, bar'},
+        )
+        self.assertEqual(res.headers['Vary'], 'Accept-Encoding')
+        self.assertNotIn('Content-Encoding', res.headers)
+        _assertBody(
+            res.body, os.path.join(here, 'fixtures/static/encoded.html')
+        )
+
+    def test_accept_gzip(self):
+        res = self._getResponse(
+            '/static/encoded.html',
+            headers={'Accept-Encoding': 'br, foo, gzip'},
+        )
+        self.assertEqual(res.headers['Vary'], 'Accept-Encoding')
+        self.assertEqual(res.headers['Content-Encoding'], 'gzip')
+        _assertBody(
+            res.body, os.path.join(here, 'fixtures/static/encoded.html.gz')
+        )
+
+    def test_accept_gzip_returns_identity(self):
+        res = self._getResponse(
+            '/static/index.html', headers={'Accept-Encoding': 'gzip'}
+        )
+        self.assertNotIn('Vary', res.headers)
+        self.assertNotIn('Content-Encoding', res.headers)
+        _assertBody(res.body, os.path.join(here, 'fixtures/static/index.html'))
+
+
 class TestStaticAppNoSubpath(unittest.TestCase):
     staticapp = static_view(os.path.join(here, 'fixtures'), use_subpath=False)
 
     def _makeRequest(self, extra):
-        from pyramid.request import Request
         from io import BytesIO
 
+        from pyramid.request import Request
+
         kw = {
             'PATH_INFO': '',
             'SCRIPT_NAME': '',
@@ -520,6 +571,48 @@ class TestExceptionViewsApp(IntegrationBase, unittest.TestCase):
         self.assertTrue(b'caught' in res.body)
 
 
+class TestSecurityApp(IntegrationBase, unittest.TestCase):
+    package = 'tests.pkgs.securityapp'
+
+    def test_public(self):
+        res = self.testapp.get('/public', status=200)
+        self.assertEqual(res.body, b'Hello')
+
+    def test_private_denied(self):
+        self.testapp.get('/private', status=403)
+
+    def test_private_allowed(self):
+        self.testapp.extra_environ = {'REMOTE_USER': 'bob'}
+        res = self.testapp.get('/private', status=200)
+        self.assertEqual(res.body, b'Secret')
+
+    def test_inaccessible(self):
+        self.testapp.get('/inaccessible', status=403)
+        self.testapp.extra_environ = {'REMOTE_USER': 'bob'}
+        self.testapp.get('/inaccessible', status=403)
+
+
+class TestLegacySecurityApp(IntegrationBase, unittest.TestCase):
+    package = 'tests.pkgs.legacysecurityapp'
+
+    def test_public(self):
+        res = self.testapp.get('/public', status=200)
+        self.assertEqual(res.body, b'Hello')
+
+    def test_private_denied(self):
+        self.testapp.get('/private', status=403)
+
+    def test_private_allowed(self):
+        self.testapp.extra_environ = {'REMOTE_USER': 'bob'}
+        res = self.testapp.get('/private', status=200)
+        self.assertEqual(res.body, b'Secret')
+
+    def test_inaccessible(self):
+        self.testapp.get('/inaccessible', status=403)
+        self.testapp.extra_environ = {'REMOTE_USER': 'bob'}
+        self.testapp.get('/inaccessible', status=403)
+
+
 class TestConflictApp(unittest.TestCase):
     package = 'tests.pkgs.conflictapp'
 
@@ -580,10 +673,12 @@ class TestConflictApp(unittest.TestCase):
     def test_overridden_authorization_policy(self):
         config = self._makeConfig()
         config.include(self.package)
-        from pyramid.testing import DummySecurityPolicy
 
-        config.set_authorization_policy(DummySecurityPolicy('fred'))
-        config.set_authentication_policy(DummySecurityPolicy(permissive=True))
+        class DummySecurityPolicy:
+            def permits(self, context, principals, permission):
+                return True
+
+        config.set_authorization_policy(DummySecurityPolicy())
         app = config.make_wsgi_app()
         self.testapp = TestApp(app)
         res = self.testapp.get('/protected', status=200)
@@ -725,8 +820,8 @@ class UnicodeInURLTest(unittest.TestCase):
         res = testapp.get(request_path, status=404)
 
         # Pyramid default 404 handler outputs:
-        # u'404 Not Found\n\nThe resource could not be found.\n\n\n'
-        # u'/avalia\xe7\xe3o_participante\n\n'
+        # '404 Not Found\n\nThe resource could not be found.\n\n\n'
+        # '/avalia\xe7\xe3o_participante\n\n'
         self.assertTrue(request_path_unicode in res.text)
 
     def test_unicode_in_url_200(self):
@@ -869,47 +964,8 @@ class AcceptContentTypeTest(unittest.TestCase):
         )
         self.assertEqual(res.content_type, 'text/x-fallback')
 
-    def test_deprecated_ranges_in_route_predicate(self):
-        config = self._makeConfig()
-        config.add_route('foo', '/foo', accept='text/*')
-        config.add_view(lambda r: 'OK', route_name='foo', renderer='string')
-        app = self._makeTestApp(config)
-        res = app.get(
-            '/foo',
-            headers={'Accept': 'application/json; q=1.0, text/plain; q=0.9'},
-            status=200,
-        )
-        self.assertEqual(res.content_type, 'text/plain')
-        self.assertEqual(res.body, b'OK')
-        res = app.get(
-            '/foo', headers={'Accept': 'application/json'}, status=404
-        )
-        self.assertEqual(res.content_type, 'application/json')
 
-    def test_deprecated_ranges_in_view_predicate(self):
-        config = self._makeConfig()
-        config.add_route('foo', '/foo')
-        config.add_view(
-            lambda r: 'OK',
-            route_name='foo',
-            accept='text/*',
-            renderer='string',
-        )
-        app = self._makeTestApp(config)
-        res = app.get(
-            '/foo',
-            headers={'Accept': 'application/json; q=1.0, text/plain; q=0.9'},
-            status=200,
-        )
-        self.assertEqual(res.content_type, 'text/plain')
-        self.assertEqual(res.body, b'OK')
-        res = app.get(
-            '/foo', headers={'Accept': 'application/json'}, status=404
-        )
-        self.assertEqual(res.content_type, 'application/json')
-
-
-class DummyContext(object):
+class DummyContext:
     pass
 
 
