@@ -1,5 +1,6 @@
 import unittest
 from zope.interface import implementer
+
 from pyramid.interfaces import ILocation
 
 
@@ -47,5 +48,5 @@ class TestLineage(unittest.TestCase):
 
 
 @implementer(ILocation)
-class Location(object):
+class Location:
     __name__ = __parent__ = None
