@@ -1,8 +1,8 @@
 import unittest
 
-from pyramid.testing import cleanUp
 from pyramid import testing
-from pyramid.compat import text_
+from pyramid.testing import cleanUp
+from pyramid.util import text_
 
 
 class TestJSON(unittest.TestCase):
@@ -63,7 +63,7 @@ class TestJSON(unittest.TestCase):
         self.assertEqual(result, '{"a": "%s"}' % now.isoformat())
 
     def test_with_custom_serializer(self):
-        class Serializer(object):
+        class Serializer:
             def __call__(self, obj, **kw):
                 self.obj = obj
                 self.kw = kw
@@ -82,7 +82,7 @@ class TestJSON(unittest.TestCase):
         request = testing.DummyRequest()
         outerself = self
 
-        class MyObject(object):
+        class MyObject:
             def __init__(self, x):
                 self.x = x
 
@@ -96,7 +96,7 @@ class TestJSON(unittest.TestCase):
         self.assertEqual(result, '[{"x": 1}, {"x": 2}]')
 
     def test_with_object_adapter_no___json__(self):
-        class MyObject(object):
+        class MyObject:
             def __init__(self, x):
                 self.x = x
 
@@ -157,20 +157,21 @@ class TestRendererHelper(unittest.TestCase):
 
     def test_instance_conforms(self):
         from zope.interface.verify import verifyObject
+
         from pyramid.interfaces import IRendererInfo
 
         helper = self._makeOne()
         verifyObject(IRendererInfo, helper)
 
     def test_settings_registry_settings_is_None(self):
-        class Dummy(object):
+        class Dummy:
             settings = None
 
         helper = self._makeOne(registry=Dummy)
         self.assertEqual(helper.settings, {})
 
     def test_settings_registry_name_is_None(self):
-        class Dummy(object):
+        class Dummy:
             settings = None
 
         helper = self._makeOne(registry=Dummy)
@@ -178,7 +179,7 @@ class TestRendererHelper(unittest.TestCase):
         self.assertEqual(helper.type, '')
 
     def test_settings_registry_settings_is_not_None(self):
-        class Dummy(object):
+        class Dummy:
             settings = {'a': 1}
 
         helper = self._makeOne(registry=Dummy)
@@ -202,7 +203,7 @@ class TestRendererHelper(unittest.TestCase):
     def _registerResponseFactory(self):
         from pyramid.interfaces import IResponseFactory
 
-        class ResponseFactory(object):
+        class ResponseFactory:
             pass
 
         self.config.registry.registerUtility(
@@ -254,7 +255,7 @@ class TestRendererHelper(unittest.TestCase):
     def test_render_explicit_registry(self):
         factory = self._registerRendererFactory()
 
-        class DummyRegistry(object):
+        class DummyRegistry:
             def __init__(self):
                 self.responses = [factory, lambda *arg: {}, None]
 
@@ -372,7 +373,7 @@ class TestRendererHelper(unittest.TestCase):
     def test_with_alternate_response_factory(self):
         from pyramid.interfaces import IResponseFactory
 
-        class ResponseFactory(object):
+        class ResponseFactory:
             def __init__(self):
                 pass
 
@@ -419,9 +420,10 @@ class TestRendererHelper(unittest.TestCase):
         registry = self.config.registry
         settings = {}
         registry.settings = settings
-        from pyramid.interfaces import IRendererFactory
         import os
 
+        from pyramid.interfaces import IRendererFactory
+
         here = os.path.dirname(os.path.abspath(__file__))
         fixture = os.path.join(here, 'fixtures/minimal.pt')
 
@@ -444,9 +446,10 @@ class TestRendererHelper(unittest.TestCase):
         registry = self.config.registry
         settings = {}
         registry.settings = settings
-        from pyramid.interfaces import IRendererFactory
         import os
 
+        from pyramid.interfaces import IRendererFactory
+
         here = os.path.dirname(os.path.abspath(__file__))
         fixture = os.path.join(here, 'fixtures/minimal.pt')
 
@@ -482,6 +485,7 @@ class TestNullRendererHelper(unittest.TestCase):
 
     def test_instance_conforms(self):
         from zope.interface.verify import verifyObject
+
         from pyramid.interfaces import IRendererInfo
 
         helper = self._makeOne()
@@ -560,7 +564,7 @@ class Test_render(unittest.TestCase):
     def test_no_response_to_preserve(self):
         from pyramid.decorator import reify
 
-        class DummyRequestWithClassResponse(object):
+        class DummyRequestWithClassResponse:
             _response = DummyResponse()
             _response.content_type = None
             _response.default_content_type = None
@@ -639,7 +643,7 @@ class Test_render_to_response(unittest.TestCase):
     def test_no_response_to_preserve(self):
         from pyramid.decorator import reify
 
-        class DummyRequestWithClassResponse(object):
+        class DummyRequestWithClassResponse:
             _response = DummyResponse()
             _response.content_type = None
             _response.default_content_type = None
@@ -655,7 +659,7 @@ class Test_render_to_response(unittest.TestCase):
         self.assertFalse('response' in request.__dict__)
 
     def test_custom_response_object(self):
-        class DummyRequestWithClassResponse(object):
+        class DummyRequestWithClassResponse:
             pass
 
         request = DummyRequestWithClassResponse()
@@ -774,7 +778,7 @@ class DummyResponse:
     body = b''
 
     # compat for renderer that will set unicode on py3
-    def _set_text(self, val):  # pragma: no cover
+    def _set_text(self, val):
         self.body = val.encode('utf8')
 
     text = property(fset=_set_text)
