@@ -1,8 +1,8 @@
 import unittest
-from pyramid import testing
 
-from pyramid.compat import PY2, text_, bytes_, native_
-from pyramid.security import AuthenticationAPIMixin, AuthorizationAPIMixin
+from pyramid import testing
+from pyramid.security import AuthenticationAPIMixin, SecurityAPIMixin
+from pyramid.util import bytes_, text_
 
 
 class TestRequest(unittest.TestCase):
@@ -23,10 +23,11 @@ class TestRequest(unittest.TestCase):
         return self._getTargetClass()(environ)
 
     def _registerResourceURL(self):
-        from pyramid.interfaces import IResourceURL
         from zope.interface import Interface
 
-        class DummyResourceURL(object):
+        from pyramid.interfaces import IResourceURL
+
+        class DummyResourceURL:
             def __init__(self, context, request):
                 self.physical_path = '/context/'
                 self.virtual_path = '/context/'
@@ -37,12 +38,14 @@ class TestRequest(unittest.TestCase):
 
     def test_class_conforms_to_IRequest(self):
         from zope.interface.verify import verifyClass
+
         from pyramid.interfaces import IRequest
 
         verifyClass(IRequest, self._getTargetClass())
 
     def test_instance_conforms_to_IRequest(self):
         from zope.interface.verify import verifyObject
+
         from pyramid.interfaces import IRequest
 
         verifyObject(IRequest, self._makeOne())
@@ -54,7 +57,7 @@ class TestRequest(unittest.TestCase):
         self.assertEqual(cls.ResponseClass, Response)
 
     def test_implements_security_apis(self):
-        apis = (AuthenticationAPIMixin, AuthorizationAPIMixin)
+        apis = (SecurityAPIMixin, AuthenticationAPIMixin)
         r = self._makeOne()
         self.assertTrue(isinstance(r, apis))
 
@@ -311,7 +314,7 @@ class TestRequest(unittest.TestCase):
         def adapter(ob):
             return object()
 
-        class Foo(object):
+        class Foo:
             pass
 
         foo = Foo()
@@ -324,7 +327,7 @@ class TestRequest(unittest.TestCase):
         request = self._makeOne()
         request.registry = self.config.registry
 
-        class Foo(object):
+        class Foo:
             pass
 
         foo = Foo()
@@ -352,10 +355,7 @@ class TestRequest(unittest.TestCase):
         inp = text_(
             b'/\xe6\xb5\x81\xe8\xa1\x8c\xe8\xb6\x8b\xe5\x8a\xbf', 'utf-8'
         )
-        if PY2:
-            body = json.dumps({'a': inp}).decode('utf-8').encode('utf-16')
-        else:
-            body = bytes(json.dumps({'a': inp}), 'utf-16')
+        body = bytes(json.dumps({'a': inp}), 'utf-16')
         request.body = body
         request.content_type = 'application/json; charset=utf-16'
         self.assertEqual(request.json_body, {'a': inp})
@@ -481,7 +481,7 @@ class Test_call_app_with_subpath_as_path_info(unittest.TestCase):
         self.assertEqual(request.environ['PATH_INFO'], '/hello/')
 
     def test_subpath_path_info_and_script_name_have_utf8(self):
-        encoded = native_(text_(b'La Pe\xc3\xb1a'))
+        encoded = text_(b'La Pe\xc3\xb1a')
         decoded = text_(bytes_(encoded), 'utf-8')
         request = DummyRequest(
             {'PATH_INFO': '/' + encoded, 'SCRIPT_NAME': '/' + encoded}
@@ -538,10 +538,6 @@ class Test_apply_request_extensions(unittest.TestCase):
         self.assertEqual(request.foo('abc'), 'abc')
 
 
-class Dummy(object):
-    pass
-
-
 class Test_subclassing_Request(unittest.TestCase):
     def test_subclass(self):
         from pyramid.interfaces import IRequest
@@ -562,10 +558,11 @@ class Test_subclassing_Request(unittest.TestCase):
         self.assertTrue(hasattr(RequestSub, '__provides__'))
 
     def test_subclass_with_implementer(self):
+        from zope.interface import implementer
+
         from pyramid.interfaces import IRequest
         from pyramid.request import Request
         from pyramid.util import InstancePropertyHelper
-        from zope.interface import implementer
 
         @implementer(IRequest)
         class RequestSub(Request):
@@ -601,14 +598,124 @@ class Test_subclassing_Request(unittest.TestCase):
         self.assertTrue(IRequest.implementedBy(RequestSub))
 
 
-class DummyRequest(object):
+class TestRequestLocalCache(unittest.TestCase):
+    def _makeOne(self, *args, **kwargs):
+        from pyramid.request import RequestLocalCache
+
+        return RequestLocalCache(*args, **kwargs)
+
+    def test_it_works_with_functions(self):
+        a = [0]
+
+        @self._makeOne()
+        def foo(request):
+            a[0] += 1
+            return a[0]
+
+        req1 = DummyRequest()
+        req2 = DummyRequest()
+        self.assertEqual(foo(req1), 1)
+        self.assertEqual(foo(req2), 2)
+        self.assertEqual(foo(req1), 1)
+        self.assertEqual(foo(req2), 2)
+        self.assertEqual(len(req1.finished_callbacks), 1)
+        self.assertEqual(len(req2.finished_callbacks), 1)
+
+    def test_clear_works(self):
+        a = [0]
+
+        @self._makeOne()
+        def foo(request):
+            a[0] += 1
+            return a[0]
+
+        req = DummyRequest()
+        self.assertEqual(foo(req), 1)
+        self.assertEqual(len(req.finished_callbacks), 1)
+        foo.cache.clear(req)
+        self.assertEqual(foo(req), 2)
+        self.assertEqual(len(req.finished_callbacks), 1)
+
+    def test_set_overrides_current_value(self):
+        a = [0]
+
+        @self._makeOne()
+        def foo(request):
+            a[0] += 1
+            return a[0]
+
+        req = DummyRequest()
+        self.assertEqual(foo(req), 1)
+        self.assertEqual(len(req.finished_callbacks), 1)
+        foo.cache.set(req, 8)
+        self.assertEqual(foo(req), 8)
+        self.assertEqual(len(req.finished_callbacks), 1)
+        self.assertEqual(foo.cache.get(req), 8)
+
+    def test_get_works(self):
+        cache = self._makeOne()
+        req = DummyRequest()
+        self.assertIs(cache.get(req), cache.NO_VALUE)
+        cache.set(req, 2)
+        self.assertIs(cache.get(req), 2)
+
+    def test_creator_in_constructor(self):
+        def foo(request):
+            return 8
+
+        cache = self._makeOne(foo)
+        req = DummyRequest()
+        result = cache.get_or_create(req)
+        self.assertEqual(result, 8)
+
+    def test_decorator_overrides_creator(self):
+        def foo(request):  # pragma: no cover
+            raise AssertionError
+
+        cache = self._makeOne(foo)
+
+        @cache
+        def bar(request):
+            return 8
+
+        req = DummyRequest()
+        result = cache.get_or_create(req)
+        self.assertEqual(result, 8)
+
+    def test_get_or_create_overrides_creator(self):
+        cache = self._makeOne()
+
+        @cache
+        def foo(request):  # pragma: no cover
+            raise AssertionError
+
+        req = DummyRequest()
+        result = cache.get_or_create(req, lambda r: 8)
+        self.assertEqual(result, 8)
+
+    def test_get_or_create_with_no_creator(self):
+        cache = self._makeOne()
+        req = DummyRequest()
+        self.assertRaises(ValueError, cache.get_or_create, req)
+
+
+class Dummy:
+    pass
+
+
+class DummyRequest:
     def __init__(self, environ=None):
         if environ is None:
             environ = {}
         self.environ = environ
+        self.response_callbacks = []
+        self.finished_callbacks = []
 
     def add_response_callback(self, callback):
-        self.response_callbacks = [callback]
+        self.response_callbacks.append(callback)
+
+    def add_finished_callback(self, callback):
+        self.finished_callbacks.append(callback)
 
     def get_response(self, app):
         return app
