@@ -124,6 +124,19 @@ class TestRouter(unittest.TestCase):
         klass = self._getTargetClass()
         return klass(self.registry)
 
+    def _mockFinishRequest(self, router):
+        """
+        Mock :meth:`pyramid.router.Router.finish_request` to be a no-op.  This
+        prevents :prop:`pyramid.request.Request.context` from being removed, so
+        we can write assertions against it.
+
+        """
+
+        def mock_finish_request(request):
+            pass
+
+        router.finish_request = mock_finish_request
+
     def _makeEnviron(self, **extras):
         environ = {
             'wsgi.url_scheme': 'http',
@@ -153,7 +166,7 @@ class TestRouter(unittest.TestCase):
     def test_request_factory(self):
         from pyramid.interfaces import IRequestFactory
 
-        class DummyRequestFactory(object):
+        class DummyRequestFactory:
             pass
 
         self.registry.registerUtility(DummyRequestFactory, IRequestFactory)
@@ -161,11 +174,9 @@ class TestRouter(unittest.TestCase):
         self.assertEqual(router.request_factory, DummyRequestFactory)
 
     def test_tween_factories(self):
-        from pyramid.interfaces import ITweens
         from pyramid.config.tweens import Tweens
+        from pyramid.interfaces import IResponse, ITweens, IViewClassifier
         from pyramid.response import Response
-        from pyramid.interfaces import IViewClassifier
-        from pyramid.interfaces import IResponse
 
         tweens = Tweens()
         self.registry.registerUtility(tweens, ITweens)
@@ -346,9 +357,8 @@ class TestRouter(unittest.TestCase):
         self.assertRaises(ValueError, router, environ, start_response)
 
     def test_call_view_returns_adapted_response(self):
+        from pyramid.interfaces import IResponse, IViewClassifier
         from pyramid.response import Response
-        from pyramid.interfaces import IViewClassifier
-        from pyramid.interfaces import IResponse
 
         context = DummyContext()
         self._registerTraverserFactory(context)
@@ -369,16 +379,18 @@ class TestRouter(unittest.TestCase):
         self.assertEqual(start_response.status, '200 OK')
 
     def test_call_with_request_extensions(self):
-        from pyramid.interfaces import IViewClassifier
-        from pyramid.interfaces import IRequestExtensions
-        from pyramid.interfaces import IRequest
+        from pyramid.interfaces import (
+            IRequest,
+            IRequestExtensions,
+            IViewClassifier,
+        )
         from pyramid.request import Request
         from pyramid.util import InstancePropertyHelper
 
         context = DummyContext()
         self._registerTraverserFactory(context)
 
-        class Extensions(object):
+        class Extensions:
             def __init__(self):
                 self.methods = {}
                 self.descriptors = {}
@@ -422,6 +434,7 @@ class TestRouter(unittest.TestCase):
         )
         self._registerRootFactory(context)
         router = self._makeOne()
+        self._mockFinishRequest(router)
         start_response = DummyStartResponse()
         result = router(environ, start_response)
         self.assertEqual(result, ['Hello world'])
@@ -434,7 +447,7 @@ class TestRouter(unittest.TestCase):
         self.assertEqual(request.root, context)
 
     def test_call_view_registered_nonspecific_nondefault_path_and_subpath(
-        self
+        self,
     ):
         from pyramid.interfaces import IViewClassifier
 
@@ -449,6 +462,7 @@ class TestRouter(unittest.TestCase):
         environ = self._makeEnviron()
         self._registerView(view, 'foo', IViewClassifier, None, None)
         router = self._makeOne()
+        self._mockFinishRequest(router)
         start_response = DummyStartResponse()
         result = router(environ, start_response)
         self.assertEqual(result, ['Hello world'])
@@ -461,14 +475,12 @@ class TestRouter(unittest.TestCase):
         self.assertEqual(request.root, context)
 
     def test_call_view_registered_specific_success(self):
-        from zope.interface import Interface
-        from zope.interface import directlyProvides
+        from zope.interface import Interface, directlyProvides
 
         class IContext(Interface):
             pass
 
-        from pyramid.interfaces import IRequest
-        from pyramid.interfaces import IViewClassifier
+        from pyramid.interfaces import IRequest, IViewClassifier
 
         context = DummyContext()
         directlyProvides(context, IContext)
@@ -480,6 +492,7 @@ class TestRouter(unittest.TestCase):
         environ = self._makeEnviron()
         self._registerView(view, '', IViewClassifier, IRequest, IContext)
         router = self._makeOne()
+        self._mockFinishRequest(router)
         start_response = DummyStartResponse()
         result = router(environ, start_response)
         self.assertEqual(result, ['Hello world'])
@@ -492,8 +505,8 @@ class TestRouter(unittest.TestCase):
         self.assertEqual(request.root, context)
 
     def test_call_view_registered_specific_fail(self):
-        from zope.interface import Interface
-        from zope.interface import directlyProvides
+        from zope.interface import Interface, directlyProvides
+
         from pyramid.httpexceptions import HTTPNotFound
         from pyramid.interfaces import IViewClassifier
 
@@ -517,15 +530,14 @@ class TestRouter(unittest.TestCase):
         self.assertRaises(HTTPNotFound, router, environ, start_response)
 
     def test_call_view_raises_forbidden(self):
-        from zope.interface import Interface
-        from zope.interface import directlyProvides
+        from zope.interface import Interface, directlyProvides
+
         from pyramid.httpexceptions import HTTPForbidden
 
         class IContext(Interface):
             pass
 
-        from pyramid.interfaces import IRequest
-        from pyramid.interfaces import IViewClassifier
+        from pyramid.interfaces import IRequest, IViewClassifier
 
         context = DummyContext()
         directlyProvides(context, IContext)
@@ -542,15 +554,13 @@ class TestRouter(unittest.TestCase):
         self.assertEqual(why.args[0], 'unauthorized')
 
     def test_call_view_raises_notfound(self):
-        from zope.interface import Interface
-        from zope.interface import directlyProvides
+        from zope.interface import Interface, directlyProvides
 
         class IContext(Interface):
             pass
 
-        from pyramid.interfaces import IRequest
-        from pyramid.interfaces import IViewClassifier
         from pyramid.httpexceptions import HTTPNotFound
+        from pyramid.interfaces import IRequest, IViewClassifier
 
         context = DummyContext()
         directlyProvides(context, IContext)
@@ -565,15 +575,14 @@ class TestRouter(unittest.TestCase):
         self.assertEqual(why.args[0], 'notfound')
 
     def test_call_view_raises_response_cleared(self):
-        from zope.interface import Interface
-        from zope.interface import directlyProvides
+        from zope.interface import Interface, directlyProvides
+
         from pyramid.interfaces import IExceptionViewClassifier
 
         class IContext(Interface):
             pass
 
-        from pyramid.interfaces import IRequest
-        from pyramid.interfaces import IViewClassifier
+        from pyramid.interfaces import IRequest, IViewClassifier
 
         context = DummyContext()
         directlyProvides(context, IContext)
@@ -599,14 +608,12 @@ class TestRouter(unittest.TestCase):
         self.assertEqual(itera, [b'OK'])
 
     def test_call_request_has_response_callbacks(self):
-        from zope.interface import Interface
-        from zope.interface import directlyProvides
+        from zope.interface import Interface, directlyProvides
 
         class IContext(Interface):
             pass
 
-        from pyramid.interfaces import IRequest
-        from pyramid.interfaces import IViewClassifier
+        from pyramid.interfaces import IRequest, IViewClassifier
 
         context = DummyContext()
         directlyProvides(context, IContext)
@@ -627,15 +634,13 @@ class TestRouter(unittest.TestCase):
         router(environ, start_response)
         self.assertEqual(response.called_back, True)
 
-    def test_call_request_has_finished_callbacks_when_view_succeeds(self):
-        from zope.interface import Interface
-        from zope.interface import directlyProvides
+    def test_finish_request_when_view_succeeds(self):
+        from zope.interface import Interface, directlyProvides
 
         class IContext(Interface):
             pass
 
-        from pyramid.interfaces import IRequest
-        from pyramid.interfaces import IViewClassifier
+        from pyramid.interfaces import IRequest, IViewClassifier
 
         context = DummyContext()
         directlyProvides(context, IContext)
@@ -647,6 +652,7 @@ class TestRouter(unittest.TestCase):
                 request.environ['called_back'] = True
 
             request.add_finished_callback(callback)
+            request.environ['request'] = request
             return response
 
         environ = self._makeEnviron()
@@ -655,16 +661,15 @@ class TestRouter(unittest.TestCase):
         start_response = DummyStartResponse()
         router(environ, start_response)
         self.assertEqual(environ['called_back'], True)
+        self.assertFalse(hasattr(environ['request'], 'context'))
 
-    def test_call_request_has_finished_callbacks_when_view_raises(self):
-        from zope.interface import Interface
-        from zope.interface import directlyProvides
+    def test_finish_request_when_view_raises(self):
+        from zope.interface import Interface, directlyProvides
 
         class IContext(Interface):
             pass
 
-        from pyramid.interfaces import IRequest
-        from pyramid.interfaces import IViewClassifier
+        from pyramid.interfaces import IRequest, IViewClassifier
 
         context = DummyContext()
         directlyProvides(context, IContext)
@@ -675,6 +680,7 @@ class TestRouter(unittest.TestCase):
                 request.environ['called_back'] = True
 
             request.add_finished_callback(callback)
+            request.environ['request'] = request
             raise NotImplementedError
 
         environ = self._makeEnviron()
@@ -683,6 +689,7 @@ class TestRouter(unittest.TestCase):
         start_response = DummyStartResponse()
         exc_raised(NotImplementedError, router, environ, start_response)
         self.assertEqual(environ['called_back'], True)
+        self.assertFalse(hasattr(environ['request'], 'context'))
 
     def test_call_request_factory_raises(self):
         # making sure finally doesnt barf when a request cannot be created
@@ -697,11 +704,13 @@ class TestRouter(unittest.TestCase):
         exc_raised(NotImplementedError, router, environ, start_response)
 
     def test_call_eventsends(self):
-        from pyramid.interfaces import INewRequest
-        from pyramid.interfaces import INewResponse
-        from pyramid.interfaces import IBeforeTraversal
-        from pyramid.interfaces import IContextFound
-        from pyramid.interfaces import IViewClassifier
+        from pyramid.interfaces import (
+            IBeforeTraversal,
+            IContextFound,
+            INewRequest,
+            INewResponse,
+            IViewClassifier,
+        )
 
         context = DummyContext()
         self._registerTraverserFactory(context)
@@ -715,6 +724,7 @@ class TestRouter(unittest.TestCase):
         context_found_events = self._registerEventListener(IContextFound)
         response_events = self._registerEventListener(INewResponse)
         router = self._makeOne()
+        self._mockFinishRequest(router)
         start_response = DummyStartResponse()
         result = router(environ, start_response)
         self.assertEqual(len(request_events), 1)
@@ -730,9 +740,11 @@ class TestRouter(unittest.TestCase):
         self.assertEqual(result, response.app_iter)
 
     def test_call_newrequest_evllist_exc_can_be_caught_by_exceptionview(self):
-        from pyramid.interfaces import INewRequest
-        from pyramid.interfaces import IExceptionViewClassifier
-        from pyramid.interfaces import IRequest
+        from pyramid.interfaces import (
+            IExceptionViewClassifier,
+            INewRequest,
+            IRequest,
+        )
 
         context = DummyContext()
         self._registerTraverserFactory(context)
@@ -776,6 +788,7 @@ class TestRouter(unittest.TestCase):
         self._registerView(view, '', IViewClassifier, None, None)
         self._registerRootFactory(context)
         router = self._makeOne()
+        self._mockFinishRequest(router)
         start_response = DummyStartResponse()
         result = router(environ, start_response)
         self.assertEqual(result, ['Hello world'])
@@ -822,10 +835,9 @@ class TestRouter(unittest.TestCase):
         )
 
     def test_call_route_matches_doesnt_overwrite_subscriber_iface(self):
-        from pyramid.interfaces import INewRequest
-        from pyramid.interfaces import IViewClassifier
-        from zope.interface import alsoProvides
-        from zope.interface import Interface
+        from zope.interface import Interface, alsoProvides
+
+        from pyramid.interfaces import INewRequest, IViewClassifier
 
         self._registerRouteRequest('foo')
 
@@ -851,6 +863,7 @@ class TestRouter(unittest.TestCase):
         self._registerView(view, '', IViewClassifier, None, None)
         self._registerRootFactory(context)
         router = self._makeOne()
+        self._mockFinishRequest(router)
         start_response = DummyStartResponse()
         result = router(environ, start_response)
         self.assertEqual(result, ['Hello world'])
@@ -867,10 +880,10 @@ class TestRouter(unittest.TestCase):
         self.assertTrue(IFoo.providedBy(request))
 
     def test_root_factory_raises_notfound(self):
-        from pyramid.interfaces import IRootFactory
+        from zope.interface import Interface, directlyProvides
+
         from pyramid.httpexceptions import HTTPNotFound
-        from zope.interface import Interface
-        from zope.interface import directlyProvides
+        from pyramid.interfaces import IRootFactory
 
         def rootfactory(request):
             raise HTTPNotFound('from root factory')
@@ -889,10 +902,10 @@ class TestRouter(unittest.TestCase):
         self.assertTrue('from root factory' in why.args[0])
 
     def test_root_factory_raises_forbidden(self):
-        from pyramid.interfaces import IRootFactory
+        from zope.interface import Interface, directlyProvides
+
         from pyramid.httpexceptions import HTTPForbidden
-        from zope.interface import Interface
-        from zope.interface import directlyProvides
+        from pyramid.interfaces import IRootFactory
 
         def rootfactory(request):
             raise HTTPForbidden('from root factory')
@@ -911,9 +924,9 @@ class TestRouter(unittest.TestCase):
         self.assertTrue('from root factory' in why.args[0])
 
     def test_root_factory_exception_propagating(self):
+        from zope.interface import Interface, directlyProvides
+
         from pyramid.interfaces import IRootFactory
-        from zope.interface import Interface
-        from zope.interface import directlyProvides
 
         def rootfactory(request):
             raise RuntimeError()
@@ -939,16 +952,17 @@ class TestRouter(unittest.TestCase):
         self.assertRaises(RuntimeError, router, environ, start_response)
 
     def test_call_view_exception_propagating(self):
-        from zope.interface import Interface
-        from zope.interface import directlyProvides
+        from zope.interface import Interface, directlyProvides
 
         class IContext(Interface):
             pass
 
-        from pyramid.interfaces import IRequest
-        from pyramid.interfaces import IViewClassifier
-        from pyramid.interfaces import IRequestFactory
-        from pyramid.interfaces import IExceptionViewClassifier
+        from pyramid.interfaces import (
+            IExceptionViewClassifier,
+            IRequest,
+            IRequestFactory,
+            IViewClassifier,
+        )
 
         def rfactory(environ):
             return request
@@ -989,9 +1003,11 @@ class TestRouter(unittest.TestCase):
         self.assertEqual(request.exc_info[:2], (RuntimeError, error))
 
     def test_call_view_raises_exception_view(self):
-        from pyramid.interfaces import IViewClassifier
-        from pyramid.interfaces import IExceptionViewClassifier
-        from pyramid.interfaces import IRequest
+        from pyramid.interfaces import (
+            IExceptionViewClassifier,
+            IRequest,
+            IViewClassifier,
+        )
 
         response = DummyResponse()
         exception_response = DummyResponse()
@@ -1017,9 +1033,11 @@ class TestRouter(unittest.TestCase):
         self.assertEqual(result, ["Hello, world"])
 
     def test_call_view_raises_super_exception_sub_exception_view(self):
-        from pyramid.interfaces import IViewClassifier
-        from pyramid.interfaces import IExceptionViewClassifier
-        from pyramid.interfaces import IRequest
+        from pyramid.interfaces import (
+            IExceptionViewClassifier,
+            IRequest,
+            IViewClassifier,
+        )
 
         class SuperException(Exception):
             pass
@@ -1046,9 +1064,11 @@ class TestRouter(unittest.TestCase):
         self.assertRaises(SuperException, router, environ, start_response)
 
     def test_call_view_raises_sub_exception_super_exception_view(self):
-        from pyramid.interfaces import IViewClassifier
-        from pyramid.interfaces import IExceptionViewClassifier
-        from pyramid.interfaces import IRequest
+        from pyramid.interfaces import (
+            IExceptionViewClassifier,
+            IRequest,
+            IViewClassifier,
+        )
 
         class SuperException(Exception):
             pass
@@ -1076,9 +1096,11 @@ class TestRouter(unittest.TestCase):
         self.assertEqual(result, ["Hello, world"])
 
     def test_call_view_raises_exception_another_exception_view(self):
-        from pyramid.interfaces import IViewClassifier
-        from pyramid.interfaces import IExceptionViewClassifier
-        from pyramid.interfaces import IRequest
+        from pyramid.interfaces import (
+            IExceptionViewClassifier,
+            IRequest,
+            IViewClassifier,
+        )
 
         class MyException(Exception):
             pass
@@ -1105,9 +1127,11 @@ class TestRouter(unittest.TestCase):
         self.assertRaises(MyException, router, environ, start_response)
 
     def test_root_factory_raises_exception_view(self):
-        from pyramid.interfaces import IRootFactory
-        from pyramid.interfaces import IRequest
-        from pyramid.interfaces import IExceptionViewClassifier
+        from pyramid.interfaces import (
+            IExceptionViewClassifier,
+            IRequest,
+            IRootFactory,
+        )
 
         def rootfactory(request):
             raise RuntimeError()
@@ -1130,8 +1154,7 @@ class TestRouter(unittest.TestCase):
         self.assertEqual(app_iter, ["Hello, world"])
 
     def test_traverser_raises_exception_view(self):
-        from pyramid.interfaces import IRequest
-        from pyramid.interfaces import IExceptionViewClassifier
+        from pyramid.interfaces import IExceptionViewClassifier, IRequest
 
         environ = self._makeEnviron()
         context = DummyContext()
@@ -1152,9 +1175,11 @@ class TestRouter(unittest.TestCase):
         self.assertEqual(result, ["Hello, world"])
 
     def test_exception_view_returns_non_iresponse(self):
-        from pyramid.interfaces import IRequest
-        from pyramid.interfaces import IViewClassifier
-        from pyramid.interfaces import IExceptionViewClassifier
+        from pyramid.interfaces import (
+            IExceptionViewClassifier,
+            IRequest,
+            IViewClassifier,
+        )
 
         environ = self._makeEnviron()
         response = DummyResponse()
@@ -1176,8 +1201,10 @@ class TestRouter(unittest.TestCase):
         self.assertRaises(ValueError, router, environ, start_response)
 
     def test_call_route_raises_route_exception_view(self):
-        from pyramid.interfaces import IViewClassifier
-        from pyramid.interfaces import IExceptionViewClassifier
+        from pyramid.interfaces import (
+            IExceptionViewClassifier,
+            IViewClassifier,
+        )
 
         req_iface = self._registerRouteRequest('foo')
         self._connectRoute('foo', 'archives/:action/:article', None)
@@ -1200,9 +1227,11 @@ class TestRouter(unittest.TestCase):
         self.assertEqual(result, ["Hello, world"])
 
     def test_call_view_raises_exception_route_view(self):
-        from pyramid.interfaces import IViewClassifier
-        from pyramid.interfaces import IExceptionViewClassifier
-        from pyramid.interfaces import IRequest
+        from pyramid.interfaces import (
+            IExceptionViewClassifier,
+            IRequest,
+            IViewClassifier,
+        )
 
         req_iface = self._registerRouteRequest('foo')
         self._connectRoute('foo', 'archives/:action/:article', None)
@@ -1224,9 +1253,11 @@ class TestRouter(unittest.TestCase):
         self.assertRaises(RuntimeError, router, environ, start_response)
 
     def test_call_route_raises_exception_view(self):
-        from pyramid.interfaces import IViewClassifier
-        from pyramid.interfaces import IExceptionViewClassifier
-        from pyramid.interfaces import IRequest
+        from pyramid.interfaces import (
+            IExceptionViewClassifier,
+            IRequest,
+            IViewClassifier,
+        )
 
         req_iface = self._registerRouteRequest('foo')
         self._connectRoute('foo', 'archives/:action/:article', None)
@@ -1249,9 +1280,11 @@ class TestRouter(unittest.TestCase):
         self.assertEqual(result, ["Hello, world"])
 
     def test_call_route_raises_super_exception_sub_exception_view(self):
-        from pyramid.interfaces import IViewClassifier
-        from pyramid.interfaces import IExceptionViewClassifier
-        from pyramid.interfaces import IRequest
+        from pyramid.interfaces import (
+            IExceptionViewClassifier,
+            IRequest,
+            IViewClassifier,
+        )
 
         class SuperException(Exception):
             pass
@@ -1279,9 +1312,11 @@ class TestRouter(unittest.TestCase):
         self.assertRaises(SuperException, router, environ, start_response)
 
     def test_call_route_raises_sub_exception_super_exception_view(self):
-        from pyramid.interfaces import IViewClassifier
-        from pyramid.interfaces import IExceptionViewClassifier
-        from pyramid.interfaces import IRequest
+        from pyramid.interfaces import (
+            IExceptionViewClassifier,
+            IRequest,
+            IViewClassifier,
+        )
 
         class SuperException(Exception):
             pass
@@ -1310,9 +1345,11 @@ class TestRouter(unittest.TestCase):
         self.assertEqual(result, ["Hello, world"])
 
     def test_call_route_raises_exception_another_exception_view(self):
-        from pyramid.interfaces import IViewClassifier
-        from pyramid.interfaces import IExceptionViewClassifier
-        from pyramid.interfaces import IRequest
+        from pyramid.interfaces import (
+            IExceptionViewClassifier,
+            IRequest,
+            IViewClassifier,
+        )
 
         class MyException(Exception):
             pass
@@ -1340,9 +1377,11 @@ class TestRouter(unittest.TestCase):
         self.assertRaises(MyException, router, environ, start_response)
 
     def test_call_route_raises_exception_view_specializing(self):
-        from pyramid.interfaces import IViewClassifier
-        from pyramid.interfaces import IExceptionViewClassifier
-        from pyramid.interfaces import IRequest
+        from pyramid.interfaces import (
+            IExceptionViewClassifier,
+            IRequest,
+            IViewClassifier,
+        )
 
         req_iface = self._registerRouteRequest('foo')
         self._connectRoute('foo', 'archives/:action/:article', None)
@@ -1375,8 +1414,10 @@ class TestRouter(unittest.TestCase):
         self.assertEqual(result, ["Hello, special world"])
 
     def test_call_route_raises_exception_view_another_route(self):
-        from pyramid.interfaces import IViewClassifier
-        from pyramid.interfaces import IExceptionViewClassifier
+        from pyramid.interfaces import (
+            IExceptionViewClassifier,
+            IViewClassifier,
+        )
 
         req_iface = self._registerRouteRequest('foo')
         another_req_iface = self._registerRouteRequest('bar')
@@ -1399,9 +1440,11 @@ class TestRouter(unittest.TestCase):
         self.assertRaises(RuntimeError, router, environ, start_response)
 
     def test_call_view_raises_exception_view_route(self):
-        from pyramid.interfaces import IRequest
-        from pyramid.interfaces import IViewClassifier
-        from pyramid.interfaces import IExceptionViewClassifier
+        from pyramid.interfaces import (
+            IExceptionViewClassifier,
+            IRequest,
+            IViewClassifier,
+        )
 
         req_iface = self._registerRouteRequest('foo')
         response = DummyResponse()
@@ -1424,8 +1467,7 @@ class TestRouter(unittest.TestCase):
 
     def test_call_view_raises_predicate_mismatch(self):
         from pyramid.exceptions import PredicateMismatch
-        from pyramid.interfaces import IViewClassifier
-        from pyramid.interfaces import IRequest
+        from pyramid.interfaces import IRequest, IViewClassifier
 
         view = DummyView(DummyResponse(), raise_exception=PredicateMismatch)
         self._registerView(view, '', IViewClassifier, IRequest, None)
@@ -1436,8 +1478,7 @@ class TestRouter(unittest.TestCase):
 
     def test_call_view_predicate_mismatch_doesnt_hide_views(self):
         from pyramid.exceptions import PredicateMismatch
-        from pyramid.interfaces import IViewClassifier
-        from pyramid.interfaces import IRequest, IResponse
+        from pyramid.interfaces import IRequest, IResponse, IViewClassifier
         from pyramid.response import Response
 
         class BaseContext:
@@ -1470,12 +1511,12 @@ class TestRouter(unittest.TestCase):
         self.assertEqual(app_iter, [b'abc'])
 
     def test_call_view_multiple_predicate_mismatches_dont_hide_views(self):
-        from pyramid.exceptions import PredicateMismatch
-        from pyramid.interfaces import IViewClassifier
-        from pyramid.interfaces import IRequest, IResponse
-        from pyramid.response import Response
         from zope.interface import Interface, implementer
 
+        from pyramid.exceptions import PredicateMismatch
+        from pyramid.interfaces import IRequest, IResponse, IViewClassifier
+        from pyramid.response import Response
+
         class IBaseContext(Interface):
             pass
 
@@ -1512,11 +1553,11 @@ class TestRouter(unittest.TestCase):
         self.assertEqual(app_iter, [b'abc'])
 
     def test_call_view_predicate_mismatch_doesnt_find_unrelated_views(self):
-        from pyramid.exceptions import PredicateMismatch
-        from pyramid.interfaces import IViewClassifier
-        from pyramid.interfaces import IRequest
         from zope.interface import Interface, implementer
 
+        from pyramid.exceptions import PredicateMismatch
+        from pyramid.interfaces import IRequest, IViewClassifier
+
         class IContext(Interface):
             pass
 
@@ -1561,10 +1602,12 @@ class TestRouter(unittest.TestCase):
         self.assertEqual(resp.status_code, 200)
         self.assertEqual(resp.body, b'foo')
 
-    def test_execution_policy_handles_exception(self):
-        from pyramid.interfaces import IViewClassifier
-        from pyramid.interfaces import IExceptionViewClassifier
-        from pyramid.interfaces import IRequest
+    def test_execution_policy_bubbles_exception(self):
+        from pyramid.interfaces import (
+            IExceptionViewClassifier,
+            IRequest,
+            IViewClassifier,
+        )
 
         class Exception1(Exception):
             pass
@@ -1591,14 +1634,13 @@ class TestRouter(unittest.TestCase):
         environ = self._makeEnviron(PATH_INFO='/archives/action1/article1')
         start_response = DummyStartResponse()
         router = self._makeOne()
-        result = router(environ, start_response)
-        self.assertEqual(result, ["Hello, world"])
+        self.assertRaises(Exception2, lambda: router(environ, start_response))
 
     def test_request_context_with_statement(self):
-        from pyramid.threadlocal import get_current_request
         from pyramid.interfaces import IExecutionPolicy
         from pyramid.request import Request
         from pyramid.response import Response
+        from pyramid.threadlocal import get_current_request
 
         registry = self.config.registry
         result = []
@@ -1618,10 +1660,10 @@ class TestRouter(unittest.TestCase):
         self.assertEqual(result[1], None)
 
     def test_request_context_manually(self):
-        from pyramid.threadlocal import get_current_request
         from pyramid.interfaces import IExecutionPolicy
         from pyramid.request import Request
         from pyramid.response import Response
+        from pyramid.threadlocal import get_current_request
 
         registry = self.config.registry
         result = []
@@ -1643,7 +1685,7 @@ class TestRouter(unittest.TestCase):
         self.assertEqual(result[1], None)
 
 
-class DummyPredicate(object):
+class DummyPredicate:
     def __call__(self, info, request):
         return True
 
@@ -1686,7 +1728,7 @@ class DummyStartResponse:
 
 
 @implementer(IResponse)
-class DummyResponse(object):
+class DummyResponse:
     headerlist = ()
     app_iter = ()
     environ = None
@@ -1700,10 +1742,6 @@ class DummyResponse(object):
         return self.app_iter
 
 
-class DummyAuthenticationPolicy:
-    pass
-
-
 class DummyLogger:
     def __init__(self):
         self.messages = []
