@@ -1,4 +1,5 @@
 import unittest
+
 from . import dummy
 
 
@@ -39,21 +40,20 @@ class TestPViewsCommand(unittest.TestCase):
         self.assertEqual(result, None)
 
     def test__find_view_no_match_multiview_registered(self):
-        from zope.interface import implementer
-        from zope.interface import providedBy
-        from pyramid.interfaces import IRequest
-        from pyramid.interfaces import IViewClassifier
-        from pyramid.interfaces import IMultiView
-        from pyramid.traversal import DefaultRootFactory
+        from zope.interface import implementer, providedBy
+
+        from pyramid.interfaces import IMultiView, IRequest, IViewClassifier
         from pyramid.registry import Registry
+        from pyramid.traversal import DefaultRootFactory
 
         registry = Registry()
 
         @implementer(IMultiView)
-        class View1(object):
+        class View1:
             pass
 
-        request = dummy.DummyRequest({'PATH_INFO': '/a'})
+        request = dummy.DummyRequest()
+        request.path_info = '/a'
         root = DefaultRootFactory(request)
         root_iface = providedBy(root)
         registry.registerAdapter(
@@ -67,18 +67,18 @@ class TestPViewsCommand(unittest.TestCase):
 
     def test__find_view_traversal(self):
         from zope.interface import providedBy
-        from pyramid.interfaces import IRequest
-        from pyramid.interfaces import IViewClassifier
-        from pyramid.interfaces import IView
-        from pyramid.traversal import DefaultRootFactory
+
+        from pyramid.interfaces import IRequest, IView, IViewClassifier
         from pyramid.registry import Registry
+        from pyramid.traversal import DefaultRootFactory
 
         registry = Registry()
 
         def view1():  # pragma: no cover
             pass
 
-        request = dummy.DummyRequest({'PATH_INFO': '/a'})
+        request = dummy.DummyRequest()
+        request.path_info = '/a'
         root = DefaultRootFactory(request)
         root_iface = providedBy(root)
         registry.registerAdapter(
@@ -91,21 +91,20 @@ class TestPViewsCommand(unittest.TestCase):
         self.assertEqual(result, view1)
 
     def test__find_view_traversal_multiview(self):
-        from zope.interface import implementer
-        from zope.interface import providedBy
-        from pyramid.interfaces import IRequest
-        from pyramid.interfaces import IViewClassifier
-        from pyramid.interfaces import IMultiView
-        from pyramid.traversal import DefaultRootFactory
+        from zope.interface import implementer, providedBy
+
+        from pyramid.interfaces import IMultiView, IRequest, IViewClassifier
         from pyramid.registry import Registry
+        from pyramid.traversal import DefaultRootFactory
 
         registry = Registry()
 
         @implementer(IMultiView)
-        class View1(object):
+        class View1:
             pass
 
-        request = dummy.DummyRequest({'PATH_INFO': '/a'})
+        request = dummy.DummyRequest()
+        request.path_info = '/a'
         root = DefaultRootFactory(request)
         root_iface = providedBy(root)
         view = View1()
@@ -119,11 +118,9 @@ class TestPViewsCommand(unittest.TestCase):
         self.assertEqual(result, view)
 
     def test__find_view_route_no_multiview(self):
-        from zope.interface import Interface
-        from zope.interface import implementer
-        from pyramid.interfaces import IRouteRequest
-        from pyramid.interfaces import IViewClassifier
-        from pyramid.interfaces import IView
+        from zope.interface import Interface, implementer
+
+        from pyramid.interfaces import IRouteRequest, IView, IViewClassifier
         from pyramid.registry import Registry
 
         registry = Registry()
@@ -143,7 +140,7 @@ class TestPViewsCommand(unittest.TestCase):
         registry.registerUtility(IMyRoute, IRouteRequest, name='a')
 
         @implementer(IMyRoot)
-        class Factory(object):
+        class Factory:
             def __init__(self, request):
                 pass
 
@@ -158,11 +155,9 @@ class TestPViewsCommand(unittest.TestCase):
         self.assertEqual(result, view)
 
     def test__find_view_route_multiview_no_view_registered(self):
-        from zope.interface import Interface
-        from zope.interface import implementer
-        from pyramid.interfaces import IRouteRequest
-        from pyramid.interfaces import IMultiView
-        from pyramid.interfaces import IRootFactory
+        from zope.interface import Interface, implementer
+
+        from pyramid.interfaces import IMultiView, IRootFactory, IRouteRequest
         from pyramid.registry import Registry
 
         registry = Registry()
@@ -186,7 +181,7 @@ class TestPViewsCommand(unittest.TestCase):
         registry.registerUtility(IMyRoute2, IRouteRequest, name='b')
 
         @implementer(IMyRoot)
-        class Factory(object):
+        class Factory:
             def __init__(self, request):
                 pass
 
@@ -202,13 +197,15 @@ class TestPViewsCommand(unittest.TestCase):
         self.assertTrue(IMultiView.providedBy(result))
 
     def test__find_view_route_multiview(self):
-        from zope.interface import Interface
-        from zope.interface import implementer
-        from pyramid.interfaces import IRouteRequest
-        from pyramid.interfaces import IViewClassifier
-        from pyramid.interfaces import IView
-        from pyramid.interfaces import IMultiView
-        from pyramid.interfaces import IRootFactory
+        from zope.interface import Interface, implementer
+
+        from pyramid.interfaces import (
+            IMultiView,
+            IRootFactory,
+            IRouteRequest,
+            IView,
+            IViewClassifier,
+        )
         from pyramid.registry import Registry
 
         registry = Registry()
@@ -238,7 +235,7 @@ class TestPViewsCommand(unittest.TestCase):
         registry.registerUtility(IMyRoute2, IRouteRequest, name='b')
 
         @implementer(IMyRoot)
-        class Factory(object):
+        class Factory:
             def __init__(self, request):
                 pass
 
@@ -267,7 +264,8 @@ class TestPViewsCommand(unittest.TestCase):
             dummy.DummyRoute('b', '/a', factory=factory, matchdict={}),
         ]
         mapper = dummy.DummyMapper(*routes)
-        request = dummy.DummyRequest({'PATH_INFO': '/a'})
+        request = dummy.DummyRequest()
+        request.path_info = '/a'
         result = command._find_multi_routes(mapper, request)
         self.assertEqual(
             result,
@@ -288,7 +286,8 @@ class TestPViewsCommand(unittest.TestCase):
             dummy.DummyRoute('b', '/a', factory=factory, matchdict={}),
         ]
         mapper = dummy.DummyMapper(*routes)
-        request = dummy.DummyRequest({'PATH_INFO': '/a'})
+        request = dummy.DummyRequest()
+        request.path_info = '/a'
         result = command._find_multi_routes(mapper, request)
         self.assertEqual(result, [{'match': {}, 'route': routes[1]}])
 
@@ -303,7 +302,8 @@ class TestPViewsCommand(unittest.TestCase):
             dummy.DummyRoute('b', '/a', factory=factory),
         ]
         mapper = dummy.DummyMapper(*routes)
-        request = dummy.DummyRequest({'PATH_INFO': '/a'})
+        request = dummy.DummyRequest()
+        request.path_info = '/a'
         result = command._find_multi_routes(mapper, request)
         self.assertEqual(result, [])
 
