@@ -1,14 +1,12 @@
-import unittest
-from zope.interface import Interface
-from zope.interface import implementer
 import sys
+import unittest
+from zope.interface import Interface, implementer
 
 from pyramid import testing
-from pyramid.interfaces import IRequest
-from pyramid.interfaces import IResponse
+from pyramid.interfaces import IRequest, IResponse
 
 
-class BaseTest(object):
+class BaseTest:
     def setUp(self):
         self.config = testing.setUp()
 
@@ -36,8 +34,8 @@ class BaseTest(object):
         return environ
 
     def _makeRequest(self, **environ):
-        from pyramid.request import Request
         from pyramid.registry import Registry
+        from pyramid.request import Request
 
         environ = self._makeEnviron(**environ)
         request = Request(environ)
@@ -100,7 +98,7 @@ class Test_notfound_view_config(BaseTest, unittest.TestCase):
         decorator.venusian = venusian
         decorator.venusian.info.scope = 'class'
 
-        class view(object):
+        class view:
             pass
 
         wrapped = decorator(view)
@@ -172,7 +170,7 @@ class Test_forbidden_view_config(BaseTest, unittest.TestCase):
         decorator.venusian = venusian
         decorator.venusian.info.scope = 'class'
 
-        class view(object):
+        class view:
             pass
 
         wrapped = decorator(view)
@@ -257,7 +255,7 @@ class Test_exception_view_config(BaseTest, unittest.TestCase):
         decorator.venusian = venusian
         decorator.venusian.info.scope = 'class'
 
-        class view(object):
+        class view:
             pass
 
         wrapped = decorator(view)
@@ -414,15 +412,14 @@ class RenderViewToIterableTests(BaseTest, unittest.TestCase):
         self.assertEqual(iterable, [b'anotherview'])
 
     def test_verify_output_bytestring(self):
-        from pyramid.request import Request
         from pyramid.config import Configurator
+        from pyramid.request import Request
         from pyramid.view import render_view
-        from webob.compat import text_type
 
         config = Configurator(settings={})
 
         def view(request):
-            request.response.text = text_type('<body></body>')
+            request.response.text = '<body></body>'
             return request.response
 
         config.add_view(name='test', view=view)
@@ -586,7 +583,7 @@ class TestViewConfigDecorator(unittest.TestCase):
         decorator.venusian = venusian
         decorator.venusian.info.scope = 'class'
 
-        class foo(object):
+        class foo:
             pass
 
         wrapped = decorator(foo)
@@ -605,7 +602,7 @@ class TestViewConfigDecorator(unittest.TestCase):
         decorator.venusian = venusian
         decorator.venusian.info.scope = 'class'
 
-        class foo(object):
+        class foo:
             pass
 
         wrapped = decorator(foo)
@@ -652,7 +649,7 @@ class TestViewConfigDecorator(unittest.TestCase):
         def bar(self):  # pragma: no cover
             pass
 
-        class foo(object):
+        class foo:
             foomethod = decorator(foo)
             barmethod = decorator(bar)
 
@@ -714,11 +711,11 @@ class TestViewConfigDecorator(unittest.TestCase):
         self.assertEqual(config.pkg, tests)
 
     def test_call_with_renderer_IRendererInfo(self):
-        import tests
         from pyramid.interfaces import IRendererInfo
+        import tests
 
         @implementer(IRendererInfo)
-        class DummyRendererHelper(object):
+        class DummyRendererHelper:
             pass
 
         renderer_helper = DummyRendererHelper()
@@ -788,14 +785,14 @@ class Test_append_slash_notfound_view(BaseTest, unittest.TestCase):
     def _registerMapper(self, reg, match=True):
         from pyramid.interfaces import IRoutesMapper
 
-        class DummyRoute(object):
+        class DummyRoute:
             def __init__(self, val):
                 self.val = val
 
             def match(self, path):
                 return self.val
 
-        class DummyMapper(object):
+        class DummyMapper:
             def __init__(self):
                 self.routelist = [DummyRoute(match)]
 
@@ -922,7 +919,7 @@ class Test_view_defaults(unittest.TestCase):
         from pyramid.view import view_defaults
 
         @view_defaults(route_name='abc', renderer='def')
-        class Foo(object):
+        class Foo:
             pass
 
         self.assertEqual(Foo.__view_defaults__['route_name'], 'abc')
@@ -932,7 +929,7 @@ class Test_view_defaults(unittest.TestCase):
         from pyramid.view import view_defaults
 
         @view_defaults(route_name='abc', renderer='def')
-        class Foo(object):
+        class Foo:
             pass
 
         class Bar(Foo):
@@ -945,7 +942,7 @@ class Test_view_defaults(unittest.TestCase):
         from pyramid.view import view_defaults
 
         @view_defaults(route_name='abc', renderer='def')
-        class Foo(object):
+        class Foo:
             pass
 
         @view_defaults(route_name='ghi')
@@ -959,7 +956,7 @@ class Test_view_defaults(unittest.TestCase):
         from pyramid.view import view_defaults
 
         @view_defaults(route_name='abc', renderer='def')
-        class Foo(object):
+        class Foo:
             pass
 
         @view_defaults()
@@ -1227,7 +1224,7 @@ class DummyRequest:
 
 
 @implementer(IResponse)
-class DummyResponse(object):
+class DummyResponse:
     headerlist = ()
     app_iter = ()
     status = '200 OK'
@@ -1244,13 +1241,13 @@ class IContext(Interface):
     pass
 
 
-class DummyVenusianInfo(object):
+class DummyVenusianInfo:
     scope = 'notaclass'
     module = sys.modules['tests']
     codeinfo = 'codeinfo'
 
 
-class DummyVenusian(object):
+class DummyVenusian:
     def __init__(self, info=None):
         if info is None:
             info = DummyVenusianInfo()
@@ -1262,11 +1259,11 @@ class DummyVenusian(object):
         return self.info
 
 
-class DummyRegistry(object):
+class DummyRegistry:
     pass
 
 
-class DummyConfig(object):
+class DummyConfig:
     def __init__(self):
         self.settings = []
         self.registry = DummyRegistry()
@@ -1281,7 +1278,7 @@ class DummyConfig(object):
         return self
 
 
-class DummyVenusianContext(object):
+class DummyVenusianContext:
     def __init__(self):
         self.config = DummyConfig()
 
